<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:cda="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:hl7v2="urn:hl7-org:v2xml"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output method="text"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <xsl:apply-templates select="/" mode="M7"/>
      <xsl:apply-templates select="/" mode="M8"/>
      <xsl:apply-templates select="/" mode="M9"/>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


   <!--PATTERN -->
   <xsl:template match="text()" priority="-1" mode="M7"/>
   <xsl:template match="@*|node()" priority="-2" mode="M7">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000Lab2PublicHealth Resultaatbericht (OUL^R22)-->


	  <!--RULE d19e9689-false-d793087e0-->
   <xsl:template match="/hl7v2:OUL_R22" priority="6391" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:MSH is required [min 1x]. (count(hl7v2:MSH)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:MSH komt te vaak voor [max 1x]. (count(hl7v2:MSH)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:NTE komt te vaak voor [max 1x]. (count(hl7v2:NTE)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.PATIENT)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.PATIENT is required [min 1x]. (count(hl7v2:OUL_R22.PATIENT)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.PATIENT)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.PATIENT komt te vaak voor [max 1x]. (count(hl7v2:OUL_R22.PATIENT)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.VISIT)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.VISIT is required [min 1x]. (count(hl7v2:OUL_R22.VISIT)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.VISIT)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.VISIT komt te vaak voor [max 1x]. (count(hl7v2:OUL_R22.VISIT)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.SPECIMEN)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.SPECIMEN is required [min 1x]. (count(hl7v2:OUL_R22.SPECIMEN)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DSC)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:DSC komt te vaak voor [max 1x]. (count(hl7v2:DSC)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH" priority="6390" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.1 is required [min 1x]. (count(hl7v2:MSH.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.1 komt te vaak voor [max 1x]. (count(hl7v2:MSH.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.2 is required [min 1x]. (count(hl7v2:MSH.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.2 komt te vaak voor [max 1x]. (count(hl7v2:MSH.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.3 is required [min 1x]. (count(hl7v2:MSH.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.3 komt te vaak voor [max 1x]. (count(hl7v2:MSH.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.4)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.4 is required [min 1x]. (count(hl7v2:MSH.4)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.4 komt te vaak voor [max 1x]. (count(hl7v2:MSH.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.5 is required [min 1x]. (count(hl7v2:MSH.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.5 komt te vaak voor [max 1x]. (count(hl7v2:MSH.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.6 is required [min 1x]. (count(hl7v2:MSH.6)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.6 komt te vaak voor [max 1x]. (count(hl7v2:MSH.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.7 is required [min 1x]. (count(hl7v2:MSH.7)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.7 komt te vaak voor [max 1x]. (count(hl7v2:MSH.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.8 komt te vaak voor [max 1x]. (count(hl7v2:MSH.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.9 is required [min 1x]. (count(hl7v2:MSH.9)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.9 komt te vaak voor [max 1x]. (count(hl7v2:MSH.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.10 is required [min 1x]. (count(hl7v2:MSH.10)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.10 komt te vaak voor [max 1x]. (count(hl7v2:MSH.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.11 is required [min 1x]. (count(hl7v2:MSH.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.11 komt te vaak voor [max 1x]. (count(hl7v2:MSH.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.12 is required [min 1x]. (count(hl7v2:MSH.12)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.12 komt te vaak voor [max 1x]. (count(hl7v2:MSH.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.13 komt te vaak voor [max 1x]. (count(hl7v2:MSH.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.14 komt te vaak voor [max 1x]. (count(hl7v2:MSH.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.15 is required [min 1x]. (count(hl7v2:MSH.15)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.15 komt te vaak voor [max 1x]. (count(hl7v2:MSH.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.16 is required [min 1x]. (count(hl7v2:MSH.16)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.16 komt te vaak voor [max 1x]. (count(hl7v2:MSH.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.17 komt te vaak voor [max 1x]. (count(hl7v2:MSH.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.18 komt te vaak voor [max 1x]. (count(hl7v2:MSH.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.19 komt te vaak voor [max 1x]. (count(hl7v2:MSH.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.20 komt te vaak voor [max 1x]. (count(hl7v2:MSH.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.21)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.21 is mandatory [min 1x]. (count(hl7v2:MSH.21)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): element hl7v2:MSH.21 komt te vaak voor [max 1x]. (count(hl7v2:MSH.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.1"
                 priority="6389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1' zijn. (string(@Item)=('1') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Field Separator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Field Separator' zijn. (string(@LongName)=('Field Separator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.2"
                 priority="6388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('2') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '2' zijn. (string(@Item)=('2') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Encoding Characters') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Encoding Characters' zijn. (string(@LongName)=('Encoding Characters') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3"
                 priority="6387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('3') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '3' zijn. (string(@Item)=('3') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70361' zijn. (string(@Table)=('HL70361') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sending Application') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Sending Application' zijn. (string(@LongName)=('Sending Application') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.1"
                 priority="6385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.2"
                 priority="6384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.3"
                 priority="6383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4"
                 priority="6381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('4') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '4' zijn. (string(@Item)=('4') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70362' zijn. (string(@Table)=('HL70362') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sending Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Sending Facility' zijn. (string(@LongName)=('Sending Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.1"
                 priority="6379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.2"
                 priority="6378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.3"
                 priority="6377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5"
                 priority="6375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('5') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '5' zijn. (string(@Item)=('5') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70361' zijn. (string(@Table)=('HL70361') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Receiving Application') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Receiving Application' zijn. (string(@LongName)=('Receiving Application') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.1"
                 priority="6373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.2"
                 priority="6372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.3"
                 priority="6371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6"
                 priority="6369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('6') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '6' zijn. (string(@Item)=('6') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70362' zijn. (string(@Table)=('HL70362') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Receiving Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Receiving Facility' zijn. (string(@LongName)=('Receiving Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.1"
                 priority="6367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.2"
                 priority="6366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.3"
                 priority="6365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.7"
                 priority="6363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('7') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '7' zijn. (string(@Item)=('7') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Date/Time Of Message' zijn. (string(@LongName)=('Date/Time Of Message') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.1"
                 priority="6361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.2"
                 priority="6360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.8"
                 priority="6358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('8') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '8' zijn. (string(@Item)=('8') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Security') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Security' zijn. (string(@LongName)=('Security') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9"
                 priority="6357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='OUL^R22^OUL_R22'"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de element content van hl7v2:MSH.9 MOET ''OUL^R22^OUL_R22'' zijn. (text()='OUL^R22^OUL_R22' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): element hl7v2:MSG.1 komt te vaak voor [max 1x]. (count(hl7v2:MSG.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): element hl7v2:MSG.2 komt te vaak voor [max 1x]. (count(hl7v2:MSG.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): element hl7v2:MSG.3 komt te vaak voor [max 1x]. (count(hl7v2:MSG.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='OUL^R22^OUL_R22'"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de element content van hl7v2:MSH.9 MOET ''OUL^R22^OUL_R22'' zijn. (text()='OUL^R22^OUL_R22' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('9') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '9' zijn. (string(@Item)=('9') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MSG') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'MSG' zijn. (string(@Type)=('MSG') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Message Type' zijn. (string(@LongName)=('Message Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.1"
                 priority="6355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70076') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Table MOET 'HL70076' zijn. (string(@Table)=('HL70076') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @LongName MOET 'Message Code' zijn. (string(@LongName)=('Message Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.2"
                 priority="6353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70003') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Table MOET 'HL70003' zijn. (string(@Table)=('HL70003') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Trigger Event') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @LongName MOET 'Trigger Event' zijn. (string(@LongName)=('Trigger Event') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.3"
                 priority="6351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70354') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Table MOET 'HL70354' zijn. (string(@Table)=('HL70354') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Structure') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @LongName MOET 'Message Structure' zijn. (string(@LongName)=('Message Structure') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.10"
                 priority="6349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('10') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '10' zijn. (string(@Item)=('10') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Control ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Message Control ID' zijn. (string(@LongName)=('Message Control ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.11"
                 priority="6348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): element hl7v2:PT.1 komt te vaak voor [max 1x]. (count(hl7v2:PT.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): element hl7v2:PT.2 komt te vaak voor [max 1x]. (count(hl7v2:PT.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('11') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '11' zijn. (string(@Item)=('11') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'PT' zijn. (string(@Type)=('PT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Processing ID' zijn. (string(@LongName)=('Processing ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.1"
                 priority="6346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70103') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @Table MOET 'HL70103' zijn. (string(@Table)=('HL70103') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @LongName MOET 'Processing ID' zijn. (string(@LongName)=('Processing ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.2"
                 priority="6344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70207') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @Table MOET 'HL70207' zijn. (string(@Table)=('HL70207') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Processing Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @LongName MOET 'Processing Mode' zijn. (string(@LongName)=('Processing Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12"
                 priority="6342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='2.5'"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de element content van hl7v2:MSH.12 MOET ''2.5'' zijn. (text()='2.5' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): element hl7v2:VID.1 komt te vaak voor [max 1x]. (count(hl7v2:VID.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): element hl7v2:VID.2 komt te vaak voor [max 1x]. (count(hl7v2:VID.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): element hl7v2:VID.3 komt te vaak voor [max 1x]. (count(hl7v2:VID.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='2.5'"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de element content van hl7v2:MSH.12 MOET ''2.5'' zijn. (text()='2.5' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('12') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '12' zijn. (string(@Item)=('12') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('VID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'VID' zijn. (string(@Type)=('VID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Version ID' zijn. (string(@LongName)=('Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.1"
                 priority="6340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70104') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @Table MOET 'HL70104' zijn. (string(@Table)=('HL70104') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @LongName MOET 'Version ID' zijn. (string(@LongName)=('Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2"
                 priority="6338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Internationalization Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @LongName MOET 'Internationalization Code' zijn. (string(@LongName)=('Internationalization Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.1"
                 priority="6336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.2"
                 priority="6335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.3"
                 priority="6334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.4"
                 priority="6332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.5"
                 priority="6331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.6"
                 priority="6330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3"
                 priority="6328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('International Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @LongName MOET 'International Version ID' zijn. (string(@LongName)=('International Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.1"
                 priority="6326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.2"
                 priority="6325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.3"
                 priority="6324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.4"
                 priority="6322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.5"
                 priority="6321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.6"
                 priority="6320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.13"
                 priority="6318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('13') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '13' zijn. (string(@Item)=('13') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Sequence Number' zijn. (string(@LongName)=('Sequence Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.14"
                 priority="6317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('14') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '14' zijn. (string(@Item)=('14') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Continuation Pointer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Continuation Pointer' zijn. (string(@LongName)=('Continuation Pointer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.15"
                 priority="6316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('15') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '15' zijn. (string(@Item)=('15') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70155' zijn. (string(@Table)=('HL70155') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Accept Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Accept Acknowledgment Type' zijn. (string(@LongName)=('Accept Acknowledgment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.16"
                 priority="6314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NE'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:MSH.16 MOET ''NE'' zijn. (text()='NE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NE'"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de element content van hl7v2:MSH.16 MOET ''NE'' zijn. (text()='NE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('16') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '16' zijn. (string(@Item)=('16') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70155' zijn. (string(@Table)=('HL70155') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Application Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Application Acknowledgment Type' zijn. (string(@LongName)=('Application Acknowledgment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.17"
                 priority="6312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NLD'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:MSH.17 MOET ''NLD'' zijn. (text()='NLD' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NLD'"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de element content van hl7v2:MSH.17 MOET ''NLD'' zijn. (text()='NLD' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('17') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '17' zijn. (string(@Item)=('17') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.18"
                 priority="6310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('692') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '692' zijn. (string(@Item)=('692') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70211') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70211' zijn. (string(@Table)=('HL70211') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Character Set') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Character Set' zijn. (string(@LongName)=('Character Set') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19"
                 priority="6308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('693') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '693' zijn. (string(@Item)=('693') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Principal Language Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Principal Language Of Message' zijn. (string(@LongName)=('Principal Language Of Message') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.1"
                 priority="6306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.2"
                 priority="6305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.3"
                 priority="6304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.4"
                 priority="6302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.5"
                 priority="6301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.6"
                 priority="6300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.20"
                 priority="6298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1317') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1317' zijn. (string(@Item)=('1317') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70356') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70356' zijn. (string(@Table)=('HL70356') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Character Set Handling Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Alternate Character Set Handling Scheme' zijn. (string(@LongName)=('Alternate Character Set Handling Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21"
                 priority="6296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1598') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1598' zijn. (string(@Item)=('1598') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Profile Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Message Profile Identifier' zijn. (string(@LongName)=('Message Profile Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.35-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.1"
                 priority="6294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.2"
                 priority="6293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.3"
                 priority="6292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.4"
                 priority="6291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE" priority="6289" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.1"
                 priority="6288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.2"
                 priority="6287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3"
                 priority="6285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="6284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="6283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="6282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4"
                 priority="6281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="6279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="6278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="6277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="6275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="6274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="6273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e9839-false-d796039e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT"
                 priority="6271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:PID is required [min 1x]. (count(hl7v2:PID)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:PID komt te vaak voor [max 1x]. (count(hl7v2:PID)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:PD1 komt te vaak voor [max 1x]. (count(hl7v2:PD1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID"
                 priority="6270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.1 komt te vaak voor [max 1x]. (count(hl7v2:PID.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.2 komt te vaak voor [max 1x]. (count(hl7v2:PID.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.3 is required [min 1x]. (count(hl7v2:PID.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.5 is required [min 1x]. (count(hl7v2:PID.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.7)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.7 is required [min 1x]. (count(hl7v2:PID.7)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.7 komt te vaak voor [max 1x]. (count(hl7v2:PID.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.8)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.8 is required [min 1x]. (count(hl7v2:PID.8)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.8 komt te vaak voor [max 1x]. (count(hl7v2:PID.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.11 is required [min 1x]. (count(hl7v2:PID.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.11 komt te vaak voor [max 1x]. (count(hl7v2:PID.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.12 komt te vaak voor [max 1x]. (count(hl7v2:PID.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.12)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.12 MAG NIET voorkomen. (count(hl7v2:PID.12)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.13)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.13 MAG NIET voorkomen. (count(hl7v2:PID.13)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.14)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.14 MAG NIET voorkomen. (count(hl7v2:PID.14)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.15 komt te vaak voor [max 1x]. (count(hl7v2:PID.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.15)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.15 MAG NIET voorkomen. (count(hl7v2:PID.15)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.16 komt te vaak voor [max 1x]. (count(hl7v2:PID.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.16)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.16 MAG NIET voorkomen. (count(hl7v2:PID.16)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.17 komt te vaak voor [max 1x]. (count(hl7v2:PID.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.17)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.17 MAG NIET voorkomen. (count(hl7v2:PID.17)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.18 komt te vaak voor [max 1x]. (count(hl7v2:PID.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.18)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.18 MAG NIET voorkomen. (count(hl7v2:PID.18)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.19 komt te vaak voor [max 1x]. (count(hl7v2:PID.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.19)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.19 MAG NIET voorkomen. (count(hl7v2:PID.19)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.20 komt te vaak voor [max 1x]. (count(hl7v2:PID.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.20)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.20 MAG NIET voorkomen. (count(hl7v2:PID.20)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.21)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.21 MAG NIET voorkomen. (count(hl7v2:PID.21)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.22)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.22 MAG NIET voorkomen. (count(hl7v2:PID.22)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.23 komt te vaak voor [max 1x]. (count(hl7v2:PID.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.23)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.23 MAG NIET voorkomen. (count(hl7v2:PID.23)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.24 komt te vaak voor [max 1x]. (count(hl7v2:PID.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.24)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.24 MAG NIET voorkomen. (count(hl7v2:PID.24)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.25 komt te vaak voor [max 1x]. (count(hl7v2:PID.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.25)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.25 MAG NIET voorkomen. (count(hl7v2:PID.25)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.26)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.26 MAG NIET voorkomen. (count(hl7v2:PID.26)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.27 komt te vaak voor [max 1x]. (count(hl7v2:PID.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.27)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.27 MAG NIET voorkomen. (count(hl7v2:PID.27)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.28 komt te vaak voor [max 1x]. (count(hl7v2:PID.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.28)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.28 MAG NIET voorkomen. (count(hl7v2:PID.28)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.29 komt te vaak voor [max 1x]. (count(hl7v2:PID.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.29)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.29 MAG NIET voorkomen. (count(hl7v2:PID.29)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.30 komt te vaak voor [max 1x]. (count(hl7v2:PID.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.30)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.30 MAG NIET voorkomen. (count(hl7v2:PID.30)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.31 komt te vaak voor [max 1x]. (count(hl7v2:PID.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.31)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.31 MAG NIET voorkomen. (count(hl7v2:PID.31)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.32)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.32 MAG NIET voorkomen. (count(hl7v2:PID.32)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.33 komt te vaak voor [max 1x]. (count(hl7v2:PID.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.33)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.33 MAG NIET voorkomen. (count(hl7v2:PID.33)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.34 komt te vaak voor [max 1x]. (count(hl7v2:PID.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.34)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.34 MAG NIET voorkomen. (count(hl7v2:PID.34)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.35 komt te vaak voor [max 1x]. (count(hl7v2:PID.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.35)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.35 MAG NIET voorkomen. (count(hl7v2:PID.35)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.36 komt te vaak voor [max 1x]. (count(hl7v2:PID.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.36)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.36 MAG NIET voorkomen. (count(hl7v2:PID.36)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.37 komt te vaak voor [max 1x]. (count(hl7v2:PID.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.37)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.37 MAG NIET voorkomen. (count(hl7v2:PID.37)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.38)&lt;=2"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.38 komt te vaak voor [max 2x]. (count(hl7v2:PID.38)&lt;=2 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.38)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.38 MAG NIET voorkomen. (count(hl7v2:PID.38)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.39)=0"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): element hl7v2:PID.39 MAG NIET voorkomen. (count(hl7v2:PID.39)=0 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.1"
                 priority="6269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('104') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '104' zijn. (string(@Item)=('104') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Set ID - PID' zijn. (string(@LongName)=('Set ID - PID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2"
                 priority="6268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('105') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '105' zijn. (string(@Item)=('105') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Patient ID' zijn. (string(@LongName)=('Patient ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.1"
                 priority="6266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.2"
                 priority="6265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.3"
                 priority="6264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4"
                 priority="6262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="6260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="6259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="6258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.5"
                 priority="6256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6"
                 priority="6254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="6252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="6251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="6250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.7"
                 priority="6248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.8"
                 priority="6247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9"
                 priority="6246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="6244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="6243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="6242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="6240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="6239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="6238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="6236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="6235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="6234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10"
                 priority="6233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="6231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="6230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="6229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="6227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="6226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="6225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="6223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="6222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="6221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3"
                 priority="6220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('106') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '106' zijn. (string(@Item)=('106') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Identifier List') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Patient Identifier List' zijn. (string(@LongName)=('Patient Identifier List') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.1"
                 priority="6218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.2"
                 priority="6217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.3"
                 priority="6216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4"
                 priority="6214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="6212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="6211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="6210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.5"
                 priority="6208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6"
                 priority="6206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="6204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="6203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="6202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.7"
                 priority="6200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.8"
                 priority="6199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9"
                 priority="6198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="6196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="6195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="6194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="6192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="6191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="6190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="6188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="6187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="6186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10"
                 priority="6185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="6183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="6182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="6181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="6179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="6178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="6177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="6175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="6174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="6173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4"
                 priority="6172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('107') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '107' zijn. (string(@Item)=('107') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Patient ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Alternate Patient ID - PID' zijn. (string(@LongName)=('Alternate Patient ID - PID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.1"
                 priority="6170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.2"
                 priority="6169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.3"
                 priority="6168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4"
                 priority="6166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.1"
                 priority="6164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.2"
                 priority="6163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.3"
                 priority="6162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.5"
                 priority="6160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6"
                 priority="6158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.1"
                 priority="6156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.2"
                 priority="6155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.3"
                 priority="6154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.7"
                 priority="6152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.8"
                 priority="6151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9"
                 priority="6150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="6148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="6147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="6146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="6144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="6143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="6142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="6140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="6139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="6138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10"
                 priority="6137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="6135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="6134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="6133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="6131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="6130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="6129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="6127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="6126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="6125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5"
                 priority="6124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('108') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '108' zijn. (string(@Item)=('108') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Patient Name' zijn. (string(@LongName)=('Patient Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1"
                 priority="6122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="6120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="6119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="6118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="6117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="6116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.2"
                 priority="6115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.3"
                 priority="6114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.4"
                 priority="6113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.5"
                 priority="6112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.6"
                 priority="6111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.7"
                 priority="6110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.8"
                 priority="6108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9"
                 priority="6106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="6104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="6103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="6102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="6100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="6099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="6098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10"
                 priority="6096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="6094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="6089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.11"
                 priority="6084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12"
                 priority="6082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="6080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="6079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13"
                 priority="6077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="6075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="6074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.14"
                 priority="6072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6"
                 priority="6071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '109' zijn. (string(@Item)=('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Mother''s Maiden Name' zijn. (string(@LongName)=('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1"
                 priority="6069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="6067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="6066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="6065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="6064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="6063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.2"
                 priority="6062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.3"
                 priority="6061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.4"
                 priority="6060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.5"
                 priority="6059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.6"
                 priority="6058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.7"
                 priority="6057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.8"
                 priority="6055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9"
                 priority="6053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="6051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="6050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="6049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="6047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="6046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="6045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10"
                 priority="6043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="6041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="6036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.11"
                 priority="6031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12"
                 priority="6029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="6027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="6026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13"
                 priority="6024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="6022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="6021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.14"
                 priority="6019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.7"
                 priority="6018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('110') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '110' zijn. (string(@Item)=('110') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Date/Time of Birth' zijn. (string(@LongName)=('Date/Time of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.1"
                 priority="6016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.2"
                 priority="6015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.8"
                 priority="6013"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.1 Administrative Sex (2013-02-10T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.1 Administrative Sex (2013-02-10T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('111') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '111' zijn. (string(@Item)=('111') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70001' zijn. (string(@Table)=('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Administrative Sex' zijn. (string(@LongName)=('Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9"
                 priority="6011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('112') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '112' zijn. (string(@Item)=('112') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Alias') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Patient Alias' zijn. (string(@LongName)=('Patient Alias') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1"
                 priority="6009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="6007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="6006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="6005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="6004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="6003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.2"
                 priority="6002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.3"
                 priority="6001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.4"
                 priority="6000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.5"
                 priority="5999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.6"
                 priority="5998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.7"
                 priority="5997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.8"
                 priority="5995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9"
                 priority="5993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="5991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="5990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="5989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="5987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="5986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="5985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10"
                 priority="5983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="5981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="5976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.11"
                 priority="5971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12"
                 priority="5969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="5967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="5966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13"
                 priority="5964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="5962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="5961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.14"
                 priority="5959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10"
                 priority="5958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('113') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '113' zijn. (string(@Item)=('113') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70005' zijn. (string(@Table)=('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Race' zijn. (string(@LongName)=('Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.1"
                 priority="5956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.2"
                 priority="5955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.3"
                 priority="5954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.4"
                 priority="5952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.5"
                 priority="5951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.6"
                 priority="5950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11"
                 priority="5948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('114') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '114' zijn. (string(@Item)=('114') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Patient Address' zijn. (string(@LongName)=('Patient Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1"
                 priority="5946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="5944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="5943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="5942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.2"
                 priority="5941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.3"
                 priority="5940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.4"
                 priority="5939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.5"
                 priority="5938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.6"
                 priority="5937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.7"
                 priority="5935"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.8"
                 priority="5933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.9"
                 priority="5932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.10"
                 priority="5931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.11"
                 priority="5930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12"
                 priority="5928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="5926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="5921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13"
                 priority="5916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="5914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="5913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14"
                 priority="5911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="5909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="5908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.12"
                 priority="5906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('115') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '115' zijn. (string(@Item)=('115') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'County Code' zijn. (string(@LongName)=('County Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13"
                 priority="5905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('116') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '116' zijn. (string(@Item)=('116') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phone Number - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Phone Number - Home' zijn. (string(@LongName)=('Phone Number - Home') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.1"
                 priority="5903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.2"
                 priority="5902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.3"
                 priority="5900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.4"
                 priority="5898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.5"
                 priority="5897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.6"
                 priority="5896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.7"
                 priority="5895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.8"
                 priority="5894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.9"
                 priority="5893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.10"
                 priority="5892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.11"
                 priority="5891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.12"
                 priority="5890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14"
                 priority="5889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('117') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '117' zijn. (string(@Item)=('117') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phone Number - Business') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Phone Number - Business' zijn. (string(@LongName)=('Phone Number - Business') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.1"
                 priority="5887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.2"
                 priority="5886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.3"
                 priority="5884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.4"
                 priority="5882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.5"
                 priority="5881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.6"
                 priority="5880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.7"
                 priority="5879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.8"
                 priority="5878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.9"
                 priority="5877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.10"
                 priority="5876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.11"
                 priority="5875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.12"
                 priority="5874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15"
                 priority="5873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '118' zijn. (string(@Item)=('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70296' zijn. (string(@Table)=('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Primary Language' zijn. (string(@LongName)=('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.1"
                 priority="5871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.2"
                 priority="5870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.3"
                 priority="5869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.4"
                 priority="5867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.5"
                 priority="5866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.6"
                 priority="5865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16"
                 priority="5863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('119') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '119' zijn. (string(@Item)=('119') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70002' zijn. (string(@Table)=('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Marital Status' zijn. (string(@LongName)=('Marital Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.1"
                 priority="5861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.2"
                 priority="5860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.3"
                 priority="5859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.4"
                 priority="5857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.5"
                 priority="5856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.6"
                 priority="5855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17"
                 priority="5853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '120' zijn. (string(@Item)=('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70006' zijn. (string(@Table)=('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Religion' zijn. (string(@LongName)=('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.1"
                 priority="5851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.2"
                 priority="5850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.3"
                 priority="5849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.4"
                 priority="5847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.5"
                 priority="5846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.6"
                 priority="5845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18"
                 priority="5843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('121') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '121' zijn. (string(@Item)=('121') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Account Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Patient Account Number' zijn. (string(@LongName)=('Patient Account Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.1"
                 priority="5841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.2"
                 priority="5840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.3"
                 priority="5839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4"
                 priority="5837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.5"
                 priority="5831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6"
                 priority="5829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.7"
                 priority="5823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.8"
                 priority="5822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9"
                 priority="5821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10"
                 priority="5808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.19"
                 priority="5795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('122') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '122' zijn. (string(@Item)=('122') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('SSN Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'SSN Number - Patient' zijn. (string(@LongName)=('SSN Number - Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20"
                 priority="5794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.1 komt te vaak voor [max 1x]. (count(hl7v2:DLN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.2 komt te vaak voor [max 1x]. (count(hl7v2:DLN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.3 komt te vaak voor [max 1x]. (count(hl7v2:DLN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('123') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '123' zijn. (string(@Item)=('123') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DLN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'DLN' zijn. (string(@Type)=('DLN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Driver''s License Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Driver''s License Number - Patient' zijn. (string(@LongName)=('Driver''s License Number - Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.1"
                 priority="5792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('License Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @LongName MOET 'License Number' zijn. (string(@LongName)=('License Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.2"
                 priority="5791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70333') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Table MOET 'HL70333' zijn. (string(@Table)=('HL70333') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Issuing State, Province, Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @LongName MOET 'Issuing State, Province, Country' zijn. (string(@LongName)=('Issuing State, Province, Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.3"
                 priority="5790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21"
                 priority="5789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('124') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '124' zijn. (string(@Item)=('124') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Mother''s Identifier' zijn. (string(@LongName)=('Mother''s Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.1"
                 priority="5787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.2"
                 priority="5786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.3"
                 priority="5785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4"
                 priority="5783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.5"
                 priority="5777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6"
                 priority="5775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.7"
                 priority="5769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.8"
                 priority="5768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9"
                 priority="5767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10"
                 priority="5754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22"
                 priority="5741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '125' zijn. (string(@Item)=('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70189' zijn. (string(@Table)=('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Ethnic Group' zijn. (string(@LongName)=('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.1"
                 priority="5739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.2"
                 priority="5738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.3"
                 priority="5737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.4"
                 priority="5735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.5"
                 priority="5734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.6"
                 priority="5733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.23"
                 priority="5731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('126') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '126' zijn. (string(@Item)=('126') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Birth Place' zijn. (string(@LongName)=('Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.24"
                 priority="5730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('127') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '127' zijn. (string(@Item)=('127') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Multiple Birth Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Multiple Birth Indicator' zijn. (string(@LongName)=('Multiple Birth Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.25"
                 priority="5728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('128') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '128' zijn. (string(@Item)=('128') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Birth Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Birth Order' zijn. (string(@LongName)=('Birth Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26"
                 priority="5727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '129' zijn. (string(@Item)=('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70171' zijn. (string(@Table)=('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Citizenship' zijn. (string(@LongName)=('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.1"
                 priority="5725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.2"
                 priority="5724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.3"
                 priority="5723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.4"
                 priority="5721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.5"
                 priority="5720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.6"
                 priority="5719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27"
                 priority="5717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('130') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '130' zijn. (string(@Item)=('130') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70172') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70172' zijn. (string(@Table)=('HL70172') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Veterans Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Veterans Military Status' zijn. (string(@LongName)=('Veterans Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.1"
                 priority="5715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.2"
                 priority="5714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.3"
                 priority="5713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.4"
                 priority="5711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.5"
                 priority="5710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.6"
                 priority="5709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28"
                 priority="5707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '739' zijn. (string(@Item)=('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70212' zijn. (string(@Table)=('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Nationality' zijn. (string(@LongName)=('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.1"
                 priority="5705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.2"
                 priority="5704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.3"
                 priority="5703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.4"
                 priority="5701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.5"
                 priority="5700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.6"
                 priority="5699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.29"
                 priority="5697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('740') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '740' zijn. (string(@Item)=('740') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Death Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Patient Death Date and Time' zijn. (string(@LongName)=('Patient Death Date and Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.1"
                 priority="5695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.2"
                 priority="5694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.30"
                 priority="5692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('741') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '741' zijn. (string(@Item)=('741') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Death Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Patient Death Indicator' zijn. (string(@LongName)=('Patient Death Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.31"
                 priority="5690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1535') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '1535' zijn. (string(@Item)=('1535') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identity Unknown Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Identity Unknown Indicator' zijn. (string(@LongName)=('Identity Unknown Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.32"
                 priority="5688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1536') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '1536' zijn. (string(@Item)=('1536') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70445') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70445' zijn. (string(@Table)=('HL70445') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identity Reliability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Identity Reliability Code' zijn. (string(@LongName)=('Identity Reliability Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.33"
                 priority="5687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1537') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '1537' zijn. (string(@Item)=('1537') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Last Update Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Last Update Date/Time' zijn. (string(@LongName)=('Last Update Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.1"
                 priority="5685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.2"
                 priority="5684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34"
                 priority="5682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1538') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '1538' zijn. (string(@Item)=('1538') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Last Update Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Last Update Facility' zijn. (string(@LongName)=('Last Update Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.1"
                 priority="5680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.2"
                 priority="5679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.3"
                 priority="5678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35"
                 priority="5676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1539') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '1539' zijn. (string(@Item)=('1539') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70446') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70446' zijn. (string(@Table)=('HL70446') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Species Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Species Code' zijn. (string(@LongName)=('Species Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.1"
                 priority="5674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.2"
                 priority="5673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.3"
                 priority="5672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.4"
                 priority="5670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.5"
                 priority="5669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.6"
                 priority="5668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36"
                 priority="5666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1540') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '1540' zijn. (string(@Item)=('1540') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70447') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70447' zijn. (string(@Table)=('HL70447') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Breed Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Breed Code' zijn. (string(@LongName)=('Breed Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.1"
                 priority="5664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.2"
                 priority="5663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.3"
                 priority="5662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.4"
                 priority="5660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.5"
                 priority="5659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.6"
                 priority="5658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.37"
                 priority="5656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1541') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '1541' zijn. (string(@Item)=('1541') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Strain') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Strain' zijn. (string(@LongName)=('Strain') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38"
                 priority="5655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1542') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '1542' zijn. (string(@Item)=('1542') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70429') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70429' zijn. (string(@Table)=('HL70429') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Production Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Production Class Code' zijn. (string(@LongName)=('Production Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.1"
                 priority="5653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.2"
                 priority="5652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.3"
                 priority="5651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.4"
                 priority="5649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.5"
                 priority="5648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.6"
                 priority="5647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39"
                 priority="5645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1840') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Item MOET '1840' zijn. (string(@Item)=('1840') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70171' zijn. (string(@Table)=('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Tribal Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Tribal Citizenship' zijn. (string(@LongName)=('Tribal Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.40-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.1"
                 priority="5643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.2"
                 priority="5642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.3"
                 priority="5641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.4"
                 priority="5639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.5"
                 priority="5638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.6"
                 priority="5637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.7"
                 priority="5635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.8"
                 priority="5634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.9"
                 priority="5633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1"
                 priority="5632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.2 komt te vaak voor [max 1x]. (count(hl7v2:PD1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.5 komt te vaak voor [max 1x]. (count(hl7v2:PD1.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.6 komt te vaak voor [max 1x]. (count(hl7v2:PD1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.7 komt te vaak voor [max 1x]. (count(hl7v2:PD1.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.8 komt te vaak voor [max 1x]. (count(hl7v2:PD1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.9 komt te vaak voor [max 1x]. (count(hl7v2:PD1.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.11 komt te vaak voor [max 1x]. (count(hl7v2:PD1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.12 komt te vaak voor [max 1x]. (count(hl7v2:PD1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.13 komt te vaak voor [max 1x]. (count(hl7v2:PD1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.16 komt te vaak voor [max 1x]. (count(hl7v2:PD1.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.17 komt te vaak voor [max 1x]. (count(hl7v2:PD1.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.18 komt te vaak voor [max 1x]. (count(hl7v2:PD1.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.19 komt te vaak voor [max 1x]. (count(hl7v2:PD1.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.20 komt te vaak voor [max 1x]. (count(hl7v2:PD1.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.21 komt te vaak voor [max 1x]. (count(hl7v2:PD1.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.1"
                 priority="5631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '755' zijn. (string(@Item)=('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70223' zijn. (string(@Table)=('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Living Dependency' zijn. (string(@LongName)=('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.2"
                 priority="5630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '742' zijn. (string(@Item)=('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70220' zijn. (string(@Table)=('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Living Arrangement' zijn. (string(@LongName)=('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3"
                 priority="5629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('756') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '756' zijn. (string(@Item)=('756') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Primary Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Patient Primary Facility' zijn. (string(@LongName)=('Patient Primary Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.1"
                 priority="5627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.2"
                 priority="5626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.3"
                 priority="5625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.4"
                 priority="5624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.5"
                 priority="5623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6"
                 priority="5621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.1"
                 priority="5619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.2"
                 priority="5618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.3"
                 priority="5617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.7"
                 priority="5615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8"
                 priority="5613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.1"
                 priority="5611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.2"
                 priority="5610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.3"
                 priority="5609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.9"
                 priority="5607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.10"
                 priority="5605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4"
                 priority="5604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('757') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '757' zijn. (string(@Item)=('757') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Patient Primary Care Provider Name &amp; ID No.' zijn. (string(@LongName)=('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.1"
                 priority="5602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2"
                 priority="5601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.3"
                 priority="5594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.4"
                 priority="5593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.5"
                 priority="5592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.6"
                 priority="5591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.7"
                 priority="5590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.8"
                 priority="5589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9"
                 priority="5588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.10"
                 priority="5582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.11"
                 priority="5580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.12"
                 priority="5579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.13"
                 priority="5577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14"
                 priority="5575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.15"
                 priority="5569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16"
                 priority="5567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17"
                 priority="5557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.18"
                 priority="5545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19"
                 priority="5543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20"
                 priority="5538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.21"
                 priority="5533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22"
                 priority="5532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23"
                 priority="5519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.5"
                 priority="5506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '745' zijn. (string(@Item)=('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70231' zijn. (string(@Table)=('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Student Indicator' zijn. (string(@LongName)=('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.6"
                 priority="5505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '753' zijn. (string(@Item)=('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70295' zijn. (string(@Table)=('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Handicap' zijn. (string(@LongName)=('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.7"
                 priority="5504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '759' zijn. (string(@Item)=('759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70315' zijn. (string(@Table)=('HL70315') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Living Will Code' zijn. (string(@LongName)=('Living Will Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.8"
                 priority="5503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '760' zijn. (string(@Item)=('760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70316' zijn. (string(@Table)=('HL70316') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Organ Donor Code' zijn. (string(@LongName)=('Organ Donor Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.9"
                 priority="5502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('761') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '761' zijn. (string(@Item)=('761') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separate Bill') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Separate Bill' zijn. (string(@LongName)=('Separate Bill') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10"
                 priority="5500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('762') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '762' zijn. (string(@Item)=('762') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duplicate Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Duplicate Patient' zijn. (string(@LongName)=('Duplicate Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.1"
                 priority="5498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.2"
                 priority="5497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.3"
                 priority="5496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4"
                 priority="5494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.5"
                 priority="5488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6"
                 priority="5486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.7"
                 priority="5480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.8"
                 priority="5479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9"
                 priority="5478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10"
                 priority="5465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11"
                 priority="5452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '743' zijn. (string(@Item)=('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70215' zijn. (string(@Table)=('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Publicity Code' zijn. (string(@LongName)=('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.1"
                 priority="5450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.2"
                 priority="5449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.3"
                 priority="5448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.4"
                 priority="5446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.5"
                 priority="5445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.6"
                 priority="5444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.12"
                 priority="5442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '744' zijn. (string(@Item)=('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Protection Indicator' zijn. (string(@LongName)=('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.13"
                 priority="5440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1566') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1566' zijn. (string(@Item)=('1566') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Protection Indicator Effective Date' zijn. (string(@LongName)=('Protection Indicator Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14"
                 priority="5439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1567') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1567' zijn. (string(@Item)=('1567') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Place of Worship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Place of Worship' zijn. (string(@LongName)=('Place of Worship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.1"
                 priority="5437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.2"
                 priority="5436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.3"
                 priority="5435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.4"
                 priority="5434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.5"
                 priority="5433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6"
                 priority="5431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.1"
                 priority="5429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.2"
                 priority="5428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.3"
                 priority="5427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.7"
                 priority="5425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8"
                 priority="5423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.1"
                 priority="5421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.2"
                 priority="5420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.3"
                 priority="5419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.9"
                 priority="5417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.10"
                 priority="5415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15"
                 priority="5414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1568') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1568' zijn. (string(@Item)=('1568') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70435' zijn. (string(@Table)=('HL70435') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Advance Directive Code' zijn. (string(@LongName)=('Advance Directive Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.1"
                 priority="5412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.2"
                 priority="5411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.3"
                 priority="5410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.4"
                 priority="5408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.5"
                 priority="5407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.6"
                 priority="5406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.16"
                 priority="5404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1569' zijn. (string(@Item)=('1569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70441') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70441' zijn. (string(@Table)=('HL70441') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Immunization Registry Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Immunization Registry Status' zijn. (string(@LongName)=('Immunization Registry Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.17"
                 priority="5403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1570' zijn. (string(@Item)=('1570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Immunization Registry Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Immunization Registry Status Effective Date' zijn. (string(@LongName)=('Immunization Registry Status Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.18"
                 priority="5402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1571' zijn. (string(@Item)=('1571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Publicity Code Effective Date' zijn. (string(@LongName)=('Publicity Code Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.19"
                 priority="5401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1572' zijn. (string(@Item)=('1572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70140') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70140' zijn. (string(@Table)=('HL70140') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Branch') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Military Branch' zijn. (string(@LongName)=('Military Branch') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.20"
                 priority="5400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('486') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '486' zijn. (string(@Item)=('486') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70141') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70141' zijn. (string(@Table)=('HL70141') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Rank/Grade') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Military Rank/Grade' zijn. (string(@LongName)=('Military Rank/Grade') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:PD1/hl7v2:PD1.21"
                 priority="5399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1573' zijn. (string(@Item)=('1573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70142') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70142' zijn. (string(@Table)=('HL70142') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Military Status' zijn. (string(@LongName)=('Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE"
                 priority="5398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.1"
                 priority="5397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.2"
                 priority="5396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3"
                 priority="5394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="5393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="5392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="5391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4"
                 priority="5390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="5388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="5387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="5386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="5384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="5383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="5382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e9848-false-d817828e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT"
                 priority="5380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:PV1 is required [min 1x]. (count(hl7v2:PV1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:PV1 komt te vaak voor [max 1x]. (count(hl7v2:PV1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:PV2 komt te vaak voor [max 1x]. (count(hl7v2:PV2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1"
                 priority="5379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.1 komt te vaak voor [max 1x]. (count(hl7v2:PV1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.2 is required [min 1x]. (count(hl7v2:PV1.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.2 komt te vaak voor [max 1x]. (count(hl7v2:PV1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.3 is required [min 1x]. (count(hl7v2:PV1.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.3 komt te vaak voor [max 1x]. (count(hl7v2:PV1.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.4 komt te vaak voor [max 1x]. (count(hl7v2:PV1.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.5 komt te vaak voor [max 1x]. (count(hl7v2:PV1.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.6 komt te vaak voor [max 1x]. (count(hl7v2:PV1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.10 is required [min 1x]. (count(hl7v2:PV1.10)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.10 komt te vaak voor [max 1x]. (count(hl7v2:PV1.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.11 komt te vaak voor [max 1x]. (count(hl7v2:PV1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.12 komt te vaak voor [max 1x]. (count(hl7v2:PV1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.13 komt te vaak voor [max 1x]. (count(hl7v2:PV1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.14 komt te vaak voor [max 1x]. (count(hl7v2:PV1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.16 komt te vaak voor [max 1x]. (count(hl7v2:PV1.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.18 komt te vaak voor [max 1x]. (count(hl7v2:PV1.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.19 komt te vaak voor [max 1x]. (count(hl7v2:PV1.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.21 komt te vaak voor [max 1x]. (count(hl7v2:PV1.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.22 komt te vaak voor [max 1x]. (count(hl7v2:PV1.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.23 komt te vaak voor [max 1x]. (count(hl7v2:PV1.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.28 komt te vaak voor [max 1x]. (count(hl7v2:PV1.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.29 komt te vaak voor [max 1x]. (count(hl7v2:PV1.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.30 komt te vaak voor [max 1x]. (count(hl7v2:PV1.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.31 komt te vaak voor [max 1x]. (count(hl7v2:PV1.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.32 komt te vaak voor [max 1x]. (count(hl7v2:PV1.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.33 komt te vaak voor [max 1x]. (count(hl7v2:PV1.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.34 komt te vaak voor [max 1x]. (count(hl7v2:PV1.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.35 komt te vaak voor [max 1x]. (count(hl7v2:PV1.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.36 komt te vaak voor [max 1x]. (count(hl7v2:PV1.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.37 komt te vaak voor [max 1x]. (count(hl7v2:PV1.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.38 komt te vaak voor [max 1x]. (count(hl7v2:PV1.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.39 is required [min 1x]. (count(hl7v2:PV1.39)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.39 komt te vaak voor [max 1x]. (count(hl7v2:PV1.39)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.40 komt te vaak voor [max 1x]. (count(hl7v2:PV1.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.41)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.41 komt te vaak voor [max 1x]. (count(hl7v2:PV1.41)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.42 komt te vaak voor [max 1x]. (count(hl7v2:PV1.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.43)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.43 komt te vaak voor [max 1x]. (count(hl7v2:PV1.43)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.44)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.44 komt te vaak voor [max 1x]. (count(hl7v2:PV1.44)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.46)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.46 komt te vaak voor [max 1x]. (count(hl7v2:PV1.46)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.47)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.47 komt te vaak voor [max 1x]. (count(hl7v2:PV1.47)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.48 komt te vaak voor [max 1x]. (count(hl7v2:PV1.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.49)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.49 komt te vaak voor [max 1x]. (count(hl7v2:PV1.49)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.50)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.50 komt te vaak voor [max 1x]. (count(hl7v2:PV1.50)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.51)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): element hl7v2:PV1.51 komt te vaak voor [max 1x]. (count(hl7v2:PV1.51)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.1"
                 priority="5378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('131') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '131' zijn. (string(@Item)=('131') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - PV1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Set ID - PV1' zijn. (string(@LongName)=('Set ID - PV1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.2"
                 priority="5377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('132') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '132' zijn. (string(@Item)=('132') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70004') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70004' zijn. (string(@Table)=('HL70004') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Patient Class' zijn. (string(@LongName)=('Patient Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3"
                 priority="5376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.6 is required [min 1x]. (count(hl7v2:PL.6)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('133') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '133' zijn. (string(@Item)=('133') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigned Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Assigned Patient Location' zijn. (string(@LongName)=('Assigned Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.1"
                 priority="5374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.2"
                 priority="5373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.3"
                 priority="5372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4"
                 priority="5371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.1"
                 priority="5369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.2"
                 priority="5368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.3"
                 priority="5367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.5"
                 priority="5365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.6"
                 priority="5364"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.411 RIVM ISIS-AR Type Afdeling (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.411 RIVM ISIS-AR Type Afdeling (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.7"
                 priority="5362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.8"
                 priority="5361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.9"
                 priority="5360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10"
                 priority="5359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.1"
                 priority="5357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.2"
                 priority="5356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.3"
                 priority="5355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.4"
                 priority="5354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11"
                 priority="5352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.1"
                 priority="5350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.2"
                 priority="5349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.3"
                 priority="5348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.4"
                 priority="5346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('134') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '134' zijn. (string(@Item)=('134') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70007') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70007' zijn. (string(@Table)=('HL70007') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admission Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Admission Type' zijn. (string(@LongName)=('Admission Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5"
                 priority="5345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('135') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '135' zijn. (string(@Item)=('135') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Preadmit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Preadmit Number' zijn. (string(@LongName)=('Preadmit Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.1"
                 priority="5343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.2"
                 priority="5342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.3"
                 priority="5341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4"
                 priority="5339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.5"
                 priority="5333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6"
                 priority="5331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.7"
                 priority="5325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.8"
                 priority="5324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9"
                 priority="5323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10"
                 priority="5310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6"
                 priority="5297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('136') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '136' zijn. (string(@Item)=('136') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Prior Patient Location' zijn. (string(@LongName)=('Prior Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.1"
                 priority="5295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.2"
                 priority="5294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.3"
                 priority="5293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4"
                 priority="5292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.1"
                 priority="5290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.2"
                 priority="5289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.3"
                 priority="5288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.5"
                 priority="5286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.6"
                 priority="5285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.7"
                 priority="5284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.8"
                 priority="5283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.9"
                 priority="5282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10"
                 priority="5281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.1"
                 priority="5279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.2"
                 priority="5278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.3"
                 priority="5277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.4"
                 priority="5276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11"
                 priority="5274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.1"
                 priority="5272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.2"
                 priority="5271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.3"
                 priority="5270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7"
                 priority="5268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('137') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '137' zijn. (string(@Item)=('137') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Attending Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Attending Doctor' zijn. (string(@LongName)=('Attending Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.1"
                 priority="5266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2"
                 priority="5265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.3"
                 priority="5258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.4"
                 priority="5257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.5"
                 priority="5256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.6"
                 priority="5255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.7"
                 priority="5254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.8"
                 priority="5253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9"
                 priority="5252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.10"
                 priority="5246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.11"
                 priority="5244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.12"
                 priority="5243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.13"
                 priority="5241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14"
                 priority="5239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.15"
                 priority="5233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16"
                 priority="5231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17"
                 priority="5221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.18"
                 priority="5209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19"
                 priority="5207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20"
                 priority="5202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.21"
                 priority="5197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22"
                 priority="5196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23"
                 priority="5183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8"
                 priority="5170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('138') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '138' zijn. (string(@Item)=('138') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Referring Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Referring Doctor' zijn. (string(@LongName)=('Referring Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.1"
                 priority="5168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2"
                 priority="5167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.3"
                 priority="5160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.4"
                 priority="5159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.5"
                 priority="5158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.6"
                 priority="5157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.7"
                 priority="5156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.8"
                 priority="5155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9"
                 priority="5154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.10"
                 priority="5148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.11"
                 priority="5146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.12"
                 priority="5145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.13"
                 priority="5143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14"
                 priority="5141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.15"
                 priority="5135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16"
                 priority="5133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17"
                 priority="5123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.18"
                 priority="5111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19"
                 priority="5109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20"
                 priority="5104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.21"
                 priority="5099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22"
                 priority="5098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23"
                 priority="5085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9"
                 priority="5072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('139') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '139' zijn. (string(@Item)=('139') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Consulting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Consulting Doctor' zijn. (string(@LongName)=('Consulting Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.1"
                 priority="5070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2"
                 priority="5069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.3"
                 priority="5062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.4"
                 priority="5061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.5"
                 priority="5060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.6"
                 priority="5059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.7"
                 priority="5058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.8"
                 priority="5057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9"
                 priority="5056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.10"
                 priority="5050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.11"
                 priority="5048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.12"
                 priority="5047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.13"
                 priority="5045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14"
                 priority="5043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.15"
                 priority="5037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16"
                 priority="5035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17"
                 priority="5025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.18"
                 priority="5013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19"
                 priority="5011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20"
                 priority="5006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.21"
                 priority="5001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22"
                 priority="5000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23"
                 priority="4987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.10"
                 priority="4974"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.1.11.2 RoleCodeNL - zorgverlenertype (personen) (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.1.11.2 RoleCodeNL - zorgverlenertype (personen) (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('140') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '140' zijn. (string(@Item)=('140') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70069') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70069' zijn. (string(@Table)=('HL70069') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Hospital Service') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Hospital Service' zijn. (string(@LongName)=('Hospital Service') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11"
                 priority="4972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('141') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '141' zijn. (string(@Item)=('141') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Temporary Location' zijn. (string(@LongName)=('Temporary Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.1"
                 priority="4970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.2"
                 priority="4969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.3"
                 priority="4968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4"
                 priority="4967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.5"
                 priority="4961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.6"
                 priority="4960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.7"
                 priority="4959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.8"
                 priority="4958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.9"
                 priority="4957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10"
                 priority="4956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11"
                 priority="4949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.12"
                 priority="4943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('142') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '142' zijn. (string(@Item)=('142') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70087') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70087' zijn. (string(@Table)=('HL70087') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Preadmit Test Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Preadmit Test Indicator' zijn. (string(@LongName)=('Preadmit Test Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.13"
                 priority="4942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('143') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '143' zijn. (string(@Item)=('143') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70092') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70092' zijn. (string(@Table)=('HL70092') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Re-admission Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Re-admission Indicator' zijn. (string(@LongName)=('Re-admission Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.14"
                 priority="4941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('144') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '144' zijn. (string(@Item)=('144') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70023') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70023' zijn. (string(@Table)=('HL70023') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Admit Source' zijn. (string(@LongName)=('Admit Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.15"
                 priority="4940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '145' zijn. (string(@Item)=('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70009' zijn. (string(@Table)=('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Ambulatory Status' zijn. (string(@LongName)=('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.16"
                 priority="4939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('146') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '146' zijn. (string(@Item)=('146') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70099' zijn. (string(@Table)=('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'VIP Indicator' zijn. (string(@LongName)=('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17"
                 priority="4938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('147') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '147' zijn. (string(@Item)=('147') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admitting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Admitting Doctor' zijn. (string(@LongName)=('Admitting Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.1"
                 priority="4936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2"
                 priority="4935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.3"
                 priority="4928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.4"
                 priority="4927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.5"
                 priority="4926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.6"
                 priority="4925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.7"
                 priority="4924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.8"
                 priority="4923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9"
                 priority="4922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.10"
                 priority="4916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.11"
                 priority="4914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.12"
                 priority="4913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.13"
                 priority="4911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14"
                 priority="4909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.15"
                 priority="4903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16"
                 priority="4901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17"
                 priority="4891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.18"
                 priority="4879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19"
                 priority="4877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20"
                 priority="4872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.21"
                 priority="4867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22"
                 priority="4866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23"
                 priority="4853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.18"
                 priority="4840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('148') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '148' zijn. (string(@Item)=('148') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70018') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70018' zijn. (string(@Table)=('HL70018') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Patient Type' zijn. (string(@LongName)=('Patient Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19"
                 priority="4839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('149') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '149' zijn. (string(@Item)=('149') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Visit Number' zijn. (string(@LongName)=('Visit Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.1"
                 priority="4837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.2"
                 priority="4836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.3"
                 priority="4835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4"
                 priority="4833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.5"
                 priority="4827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6"
                 priority="4825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.7"
                 priority="4819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.8"
                 priority="4818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9"
                 priority="4817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10"
                 priority="4804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20"
                 priority="4791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.1 komt te vaak voor [max 1x]. (count(hl7v2:FC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.2 komt te vaak voor [max 1x]. (count(hl7v2:FC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('150') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '150' zijn. (string(@Item)=('150') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'FC' zijn. (string(@Type)=('FC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70064' zijn. (string(@Table)=('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Financial Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Financial Class' zijn. (string(@LongName)=('Financial Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.1"
                 priority="4789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Table MOET 'HL70064' zijn. (string(@Table)=('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Financial Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @LongName MOET 'Financial Class Code' zijn. (string(@LongName)=('Financial Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2"
                 priority="4788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.1"
                 priority="4786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.2"
                 priority="4785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.21"
                 priority="4783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('151') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '151' zijn. (string(@Item)=('151') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70032') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70032' zijn. (string(@Table)=('HL70032') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge Price Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Charge Price Indicator' zijn. (string(@LongName)=('Charge Price Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.22"
                 priority="4782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('152') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '152' zijn. (string(@Item)=('152') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70045') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70045' zijn. (string(@Table)=('HL70045') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Courtesy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Courtesy Code' zijn. (string(@LongName)=('Courtesy Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.23"
                 priority="4781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('153') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '153' zijn. (string(@Item)=('153') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70046') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70046' zijn. (string(@Table)=('HL70046') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Credit Rating') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Credit Rating' zijn. (string(@LongName)=('Credit Rating') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.24"
                 priority="4780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('154') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '154' zijn. (string(@Item)=('154') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70044') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70044' zijn. (string(@Table)=('HL70044') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Contract Code' zijn. (string(@LongName)=('Contract Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.25"
                 priority="4779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('155') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '155' zijn. (string(@Item)=('155') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Contract Effective Date' zijn. (string(@LongName)=('Contract Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.26"
                 priority="4778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('156') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '156' zijn. (string(@Item)=('156') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Contract Amount' zijn. (string(@LongName)=('Contract Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.27"
                 priority="4777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('157') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '157' zijn. (string(@Item)=('157') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Period') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Contract Period' zijn. (string(@LongName)=('Contract Period') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.28"
                 priority="4776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('158') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '158' zijn. (string(@Item)=('158') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70073') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70073' zijn. (string(@Table)=('HL70073') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interest Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Interest Code' zijn. (string(@LongName)=('Interest Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.29"
                 priority="4775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('159') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '159' zijn. (string(@Item)=('159') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70110') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70110' zijn. (string(@Table)=('HL70110') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer to Bad Debt Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Transfer to Bad Debt Code' zijn. (string(@LongName)=('Transfer to Bad Debt Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.30"
                 priority="4774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('160') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '160' zijn. (string(@Item)=('160') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer to Bad Debt Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Transfer to Bad Debt Date' zijn. (string(@LongName)=('Transfer to Bad Debt Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.31"
                 priority="4773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('161') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '161' zijn. (string(@Item)=('161') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70021') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70021' zijn. (string(@Table)=('HL70021') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Agency Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Bad Debt Agency Code' zijn. (string(@LongName)=('Bad Debt Agency Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.32"
                 priority="4772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('162') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '162' zijn. (string(@Item)=('162') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Transfer Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Bad Debt Transfer Amount' zijn. (string(@LongName)=('Bad Debt Transfer Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.33"
                 priority="4771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('163') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '163' zijn. (string(@Item)=('163') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Recovery Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Bad Debt Recovery Amount' zijn. (string(@LongName)=('Bad Debt Recovery Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.34"
                 priority="4770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('164') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '164' zijn. (string(@Item)=('164') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70111') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70111' zijn. (string(@Table)=('HL70111') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Delete Account Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Delete Account Indicator' zijn. (string(@LongName)=('Delete Account Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.35"
                 priority="4769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('165') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '165' zijn. (string(@Item)=('165') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Delete Account Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Delete Account Date' zijn. (string(@LongName)=('Delete Account Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.36"
                 priority="4768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('166') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '166' zijn. (string(@Item)=('166') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70112' zijn. (string(@Table)=('HL70112') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Discharge Disposition' zijn. (string(@LongName)=('Discharge Disposition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37"
                 priority="4767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): element hl7v2:DLD.1 komt te vaak voor [max 1x]. (count(hl7v2:DLD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): element hl7v2:DLD.2 komt te vaak voor [max 1x]. (count(hl7v2:DLD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('167') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '167' zijn. (string(@Item)=('167') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DLD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'DLD' zijn. (string(@Type)=('DLD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70113' zijn. (string(@Table)=('HL70113') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharged to Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Discharged to Location' zijn. (string(@LongName)=('Discharged to Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.1"
                 priority="4765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @Table MOET 'HL70113' zijn. (string(@Table)=('HL70113') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @LongName MOET 'Discharge Location' zijn. (string(@LongName)=('Discharge Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2"
                 priority="4764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.1"
                 priority="4762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.2"
                 priority="4761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38"
                 priority="4759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('168') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '168' zijn. (string(@Item)=('168') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70114') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70114' zijn. (string(@Table)=('HL70114') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diet Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Diet Type' zijn. (string(@LongName)=('Diet Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.1"
                 priority="4757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.2"
                 priority="4756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.3"
                 priority="4755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.4"
                 priority="4753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.5"
                 priority="4752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.6"
                 priority="4751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.39"
                 priority="4749"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.412 RIVM ISIS-AR Instellingstypen (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.412 RIVM ISIS-AR Instellingstypen (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('169') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '169' zijn. (string(@Item)=('169') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70115') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70115' zijn. (string(@Table)=('HL70115') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Servicing Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Servicing Facility' zijn. (string(@LongName)=('Servicing Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.40"
                 priority="4747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('170') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '170' zijn. (string(@Item)=('170') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70116') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70116' zijn. (string(@Table)=('HL70116') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Bed Status' zijn. (string(@LongName)=('Bed Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.41"
                 priority="4746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('171') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '171' zijn. (string(@Item)=('171') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70117') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70117' zijn. (string(@Table)=('HL70117') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Account Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Account Status' zijn. (string(@LongName)=('Account Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42"
                 priority="4745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('172') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '172' zijn. (string(@Item)=('172') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Pending Location' zijn. (string(@LongName)=('Pending Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.1"
                 priority="4743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.2"
                 priority="4742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.3"
                 priority="4741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4"
                 priority="4740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.5"
                 priority="4734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.6"
                 priority="4733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.7"
                 priority="4732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.8"
                 priority="4731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.9"
                 priority="4730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10"
                 priority="4729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11"
                 priority="4722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43"
                 priority="4716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('173') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '173' zijn. (string(@Item)=('173') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Prior Temporary Location' zijn. (string(@LongName)=('Prior Temporary Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.1"
                 priority="4714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.2"
                 priority="4713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.3"
                 priority="4712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4"
                 priority="4711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.5"
                 priority="4705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.6"
                 priority="4704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.7"
                 priority="4703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.8"
                 priority="4702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.9"
                 priority="4701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10"
                 priority="4700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11"
                 priority="4693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.44"
                 priority="4687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('174') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '174' zijn. (string(@Item)=('174') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Admit Date/Time' zijn. (string(@LongName)=('Admit Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.1"
                 priority="4685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.2"
                 priority="4684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.45"
                 priority="4682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('175') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '175' zijn. (string(@Item)=('175') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Discharge Date/Time' zijn. (string(@LongName)=('Discharge Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.1"
                 priority="4680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.2"
                 priority="4679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.46"
                 priority="4677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('176') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '176' zijn. (string(@Item)=('176') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Current Patient Balance') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Current Patient Balance' zijn. (string(@LongName)=('Current Patient Balance') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.47"
                 priority="4676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('177') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '177' zijn. (string(@Item)=('177') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Charges') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Total Charges' zijn. (string(@LongName)=('Total Charges') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.48"
                 priority="4675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('178') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '178' zijn. (string(@Item)=('178') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Adjustments') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Total Adjustments' zijn. (string(@LongName)=('Total Adjustments') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.49"
                 priority="4674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('179') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '179' zijn. (string(@Item)=('179') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Payments') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Total Payments' zijn. (string(@LongName)=('Total Payments') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50"
                 priority="4673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('180') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '180' zijn. (string(@Item)=('180') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Visit ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Alternate Visit ID' zijn. (string(@LongName)=('Alternate Visit ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.1"
                 priority="4671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.2"
                 priority="4670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.3"
                 priority="4669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4"
                 priority="4667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.5"
                 priority="4661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6"
                 priority="4659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.7"
                 priority="4653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.8"
                 priority="4652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9"
                 priority="4651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10"
                 priority="4638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.51"
                 priority="4625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '1226' zijn. (string(@Item)=('1226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70326') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70326' zijn. (string(@Table)=('HL70326') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Visit Indicator' zijn. (string(@LongName)=('Visit Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52"
                 priority="4624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1274') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Item MOET '1274' zijn. (string(@Item)=('1274') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Healthcare Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Other Healthcare Provider' zijn. (string(@LongName)=('Other Healthcare Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.41-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.1"
                 priority="4622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2"
                 priority="4621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.3"
                 priority="4614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.4"
                 priority="4613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.5"
                 priority="4612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.6"
                 priority="4611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.7"
                 priority="4610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.8"
                 priority="4609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9"
                 priority="4608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.10"
                 priority="4602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.11"
                 priority="4600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.12"
                 priority="4599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.13"
                 priority="4597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14"
                 priority="4595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.15"
                 priority="4589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16"
                 priority="4587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17"
                 priority="4577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.18"
                 priority="4565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19"
                 priority="4563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20"
                 priority="4558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.21"
                 priority="4553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22"
                 priority="4552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23"
                 priority="4539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2"
                 priority="4526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.1 komt te vaak voor [max 1x]. (count(hl7v2:PV2.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.2 komt te vaak voor [max 1x]. (count(hl7v2:PV2.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.3 komt te vaak voor [max 1x]. (count(hl7v2:PV2.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.4 komt te vaak voor [max 1x]. (count(hl7v2:PV2.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.6 komt te vaak voor [max 1x]. (count(hl7v2:PV2.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.8 komt te vaak voor [max 1x]. (count(hl7v2:PV2.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.9 komt te vaak voor [max 1x]. (count(hl7v2:PV2.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.10 komt te vaak voor [max 1x]. (count(hl7v2:PV2.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.11 komt te vaak voor [max 1x]. (count(hl7v2:PV2.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.12 komt te vaak voor [max 1x]. (count(hl7v2:PV2.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.14 komt te vaak voor [max 1x]. (count(hl7v2:PV2.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.15 komt te vaak voor [max 1x]. (count(hl7v2:PV2.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.16 komt te vaak voor [max 1x]. (count(hl7v2:PV2.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.17 komt te vaak voor [max 1x]. (count(hl7v2:PV2.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.18 komt te vaak voor [max 1x]. (count(hl7v2:PV2.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.19 komt te vaak voor [max 1x]. (count(hl7v2:PV2.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.20 komt te vaak voor [max 1x]. (count(hl7v2:PV2.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.21 komt te vaak voor [max 1x]. (count(hl7v2:PV2.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.22 komt te vaak voor [max 1x]. (count(hl7v2:PV2.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.24 komt te vaak voor [max 1x]. (count(hl7v2:PV2.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.25 komt te vaak voor [max 1x]. (count(hl7v2:PV2.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.26 komt te vaak voor [max 1x]. (count(hl7v2:PV2.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.27 komt te vaak voor [max 1x]. (count(hl7v2:PV2.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.28 komt te vaak voor [max 1x]. (count(hl7v2:PV2.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.29 komt te vaak voor [max 1x]. (count(hl7v2:PV2.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.30 komt te vaak voor [max 1x]. (count(hl7v2:PV2.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.31 komt te vaak voor [max 1x]. (count(hl7v2:PV2.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.32 komt te vaak voor [max 1x]. (count(hl7v2:PV2.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.33 komt te vaak voor [max 1x]. (count(hl7v2:PV2.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.34 komt te vaak voor [max 1x]. (count(hl7v2:PV2.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.35 komt te vaak voor [max 1x]. (count(hl7v2:PV2.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.36 komt te vaak voor [max 1x]. (count(hl7v2:PV2.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.37 komt te vaak voor [max 1x]. (count(hl7v2:PV2.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.38 komt te vaak voor [max 1x]. (count(hl7v2:PV2.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.40 komt te vaak voor [max 1x]. (count(hl7v2:PV2.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.42 komt te vaak voor [max 1x]. (count(hl7v2:PV2.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.43)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.43 komt te vaak voor [max 1x]. (count(hl7v2:PV2.43)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.44)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.44 komt te vaak voor [max 1x]. (count(hl7v2:PV2.44)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.46)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.46 komt te vaak voor [max 1x]. (count(hl7v2:PV2.46)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.47)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.47 komt te vaak voor [max 1x]. (count(hl7v2:PV2.47)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.48 komt te vaak voor [max 1x]. (count(hl7v2:PV2.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1"
                 priority="4525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('181') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '181' zijn. (string(@Item)=('181') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Prior Pending Location' zijn. (string(@LongName)=('Prior Pending Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.1"
                 priority="4523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.2"
                 priority="4522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.3"
                 priority="4521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4"
                 priority="4520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.5"
                 priority="4514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.6"
                 priority="4513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.7"
                 priority="4512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.8"
                 priority="4511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.9"
                 priority="4510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10"
                 priority="4509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11"
                 priority="4502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2"
                 priority="4496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('182') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '182' zijn. (string(@Item)=('182') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70129') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70129' zijn. (string(@Table)=('HL70129') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Accommodation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Accommodation Code' zijn. (string(@LongName)=('Accommodation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.1"
                 priority="4494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.2"
                 priority="4493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.3"
                 priority="4492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.4"
                 priority="4490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.5"
                 priority="4489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.6"
                 priority="4488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3"
                 priority="4486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('183') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '183' zijn. (string(@Item)=('183') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Admit Reason' zijn. (string(@LongName)=('Admit Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.1"
                 priority="4484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.2"
                 priority="4483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.3"
                 priority="4482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.4"
                 priority="4480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.5"
                 priority="4479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.6"
                 priority="4478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4"
                 priority="4476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('184') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '184' zijn. (string(@Item)=('184') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Transfer Reason' zijn. (string(@LongName)=('Transfer Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.1"
                 priority="4474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.2"
                 priority="4473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.3"
                 priority="4472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.4"
                 priority="4470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.5"
                 priority="4469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.6"
                 priority="4468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.5"
                 priority="4466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('185') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '185' zijn. (string(@Item)=('185') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Valuables') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Valuables' zijn. (string(@LongName)=('Patient Valuables') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.6"
                 priority="4465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('186') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '186' zijn. (string(@Item)=('186') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Valuables Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Valuables Location' zijn. (string(@LongName)=('Patient Valuables Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.7"
                 priority="4464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('187') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '187' zijn. (string(@Item)=('187') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70130') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70130' zijn. (string(@Table)=('HL70130') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit User Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit User Code' zijn. (string(@LongName)=('Visit User Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.8"
                 priority="4463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('188') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '188' zijn. (string(@Item)=('188') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Admit Date/Time' zijn. (string(@LongName)=('Expected Admit Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.1"
                 priority="4461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.2"
                 priority="4460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.9"
                 priority="4458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('189') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '189' zijn. (string(@Item)=('189') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Discharge Date/Time' zijn. (string(@LongName)=('Expected Discharge Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.1"
                 priority="4456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.2"
                 priority="4455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.10"
                 priority="4453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('711') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '711' zijn. (string(@Item)=('711') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Estimated Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Estimated Length of Inpatient Stay' zijn. (string(@LongName)=('Estimated Length of Inpatient Stay') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.11"
                 priority="4452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('712') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '712' zijn. (string(@Item)=('712') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Actual Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Actual Length of Inpatient Stay' zijn. (string(@LongName)=('Actual Length of Inpatient Stay') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.12"
                 priority="4451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('713') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '713' zijn. (string(@Item)=('713') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Description' zijn. (string(@LongName)=('Visit Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13"
                 priority="4450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('714') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '714' zijn. (string(@Item)=('714') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Referral Source Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Referral Source Code' zijn. (string(@LongName)=('Referral Source Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.1"
                 priority="4448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2"
                 priority="4447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.3"
                 priority="4440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.4"
                 priority="4439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.5"
                 priority="4438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.6"
                 priority="4437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.7"
                 priority="4436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.8"
                 priority="4435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9"
                 priority="4434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.10"
                 priority="4428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.11"
                 priority="4426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.12"
                 priority="4425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.13"
                 priority="4423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14"
                 priority="4421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.15"
                 priority="4415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16"
                 priority="4413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17"
                 priority="4403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.18"
                 priority="4391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19"
                 priority="4389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20"
                 priority="4384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.21"
                 priority="4379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22"
                 priority="4378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23"
                 priority="4365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.14"
                 priority="4352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('715') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '715' zijn. (string(@Item)=('715') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Previous Service Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Previous Service Date' zijn. (string(@LongName)=('Previous Service Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.15"
                 priority="4351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('716') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '716' zijn. (string(@Item)=('716') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Employment Illness Related Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Employment Illness Related Indicator' zijn. (string(@LongName)=('Employment Illness Related Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.16"
                 priority="4349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('717') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '717' zijn. (string(@Item)=('717') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70213') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70213' zijn. (string(@Table)=('HL70213') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Purge Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Purge Status Code' zijn. (string(@LongName)=('Purge Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.17"
                 priority="4348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('718') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '718' zijn. (string(@Item)=('718') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Purge Status Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Purge Status Date' zijn. (string(@LongName)=('Purge Status Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.18"
                 priority="4347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('719') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '719' zijn. (string(@Item)=('719') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70214') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70214' zijn. (string(@Table)=('HL70214') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Program Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Special Program Code' zijn. (string(@LongName)=('Special Program Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.19"
                 priority="4346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('720') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '720' zijn. (string(@Item)=('720') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Retention Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Retention Indicator' zijn. (string(@LongName)=('Retention Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.20"
                 priority="4344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('721') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '721' zijn. (string(@Item)=('721') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Number of Insurance Plans') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Number of Insurance Plans' zijn. (string(@LongName)=('Expected Number of Insurance Plans') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.21"
                 priority="4343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('722') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '722' zijn. (string(@Item)=('722') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70215' zijn. (string(@Table)=('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Publicity Code' zijn. (string(@LongName)=('Visit Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.22"
                 priority="4342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('723') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '723' zijn. (string(@Item)=('723') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Protection Indicator' zijn. (string(@LongName)=('Visit Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23"
                 priority="4340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('724') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '724' zijn. (string(@Item)=('724') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Clinic Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Clinic Organization Name' zijn. (string(@LongName)=('Clinic Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.1"
                 priority="4338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.2"
                 priority="4337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.3"
                 priority="4336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.4"
                 priority="4335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.5"
                 priority="4334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6"
                 priority="4332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.1"
                 priority="4330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.2"
                 priority="4329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.3"
                 priority="4328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.7"
                 priority="4326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8"
                 priority="4324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.1"
                 priority="4322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.2"
                 priority="4321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.3"
                 priority="4320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.9"
                 priority="4318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.10"
                 priority="4316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.24"
                 priority="4315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('725') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '725' zijn. (string(@Item)=('725') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70216') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70216' zijn. (string(@Table)=('HL70216') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Status Code' zijn. (string(@LongName)=('Patient Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.25"
                 priority="4314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('726') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '726' zijn. (string(@Item)=('726') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70217') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70217' zijn. (string(@Table)=('HL70217') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Priority Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Priority Code' zijn. (string(@LongName)=('Visit Priority Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.26"
                 priority="4313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('727') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '727' zijn. (string(@Item)=('727') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Previous Treatment Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Previous Treatment Date' zijn. (string(@LongName)=('Previous Treatment Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.27"
                 priority="4312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('728') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '728' zijn. (string(@Item)=('728') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70112' zijn. (string(@Table)=('HL70112') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Discharge Disposition' zijn. (string(@LongName)=('Expected Discharge Disposition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.28"
                 priority="4311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('729') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '729' zijn. (string(@Item)=('729') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Signature on File Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Signature on File Date' zijn. (string(@LongName)=('Signature on File Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.29"
                 priority="4310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('730') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '730' zijn. (string(@Item)=('730') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('First Similar Illness Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'First Similar Illness Date' zijn. (string(@LongName)=('First Similar Illness Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30"
                 priority="4309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('731') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '731' zijn. (string(@Item)=('731') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70218') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70218' zijn. (string(@Table)=('HL70218') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Charge Adjustment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Charge Adjustment Code' zijn. (string(@LongName)=('Patient Charge Adjustment Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.1"
                 priority="4307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.2"
                 priority="4306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.3"
                 priority="4305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.4"
                 priority="4303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.5"
                 priority="4302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.6"
                 priority="4301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.31"
                 priority="4299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('732') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '732' zijn. (string(@Item)=('732') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70219') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70219' zijn. (string(@Table)=('HL70219') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Recurring Service Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Recurring Service Code' zijn. (string(@LongName)=('Recurring Service Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.32"
                 priority="4298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('733') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '733' zijn. (string(@Item)=('733') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Billing Media Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Billing Media Code' zijn. (string(@LongName)=('Billing Media Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.33"
                 priority="4296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('734') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '734' zijn. (string(@Item)=('734') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Surgery Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Surgery Date and Time' zijn. (string(@LongName)=('Expected Surgery Date and Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.1"
                 priority="4294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.2"
                 priority="4293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.34"
                 priority="4291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('735') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '735' zijn. (string(@Item)=('735') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Partnership Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Military Partnership Code' zijn. (string(@LongName)=('Military Partnership Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.35"
                 priority="4289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('736') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '736' zijn. (string(@Item)=('736') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Non-Availability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Military Non-Availability Code' zijn. (string(@LongName)=('Military Non-Availability Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.36"
                 priority="4287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('737') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '737' zijn. (string(@Item)=('737') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Newborn Baby Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Newborn Baby Indicator' zijn. (string(@LongName)=('Newborn Baby Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.37"
                 priority="4285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('738') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '738' zijn. (string(@Item)=('738') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Baby Detained Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Baby Detained Indicator' zijn. (string(@LongName)=('Baby Detained Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38"
                 priority="4283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1543') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1543' zijn. (string(@Item)=('1543') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70430') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70430' zijn. (string(@Table)=('HL70430') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mode of Arrival Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Mode of Arrival Code' zijn. (string(@LongName)=('Mode of Arrival Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.1"
                 priority="4281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.2"
                 priority="4280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.3"
                 priority="4279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.4"
                 priority="4277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.5"
                 priority="4276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.6"
                 priority="4275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39"
                 priority="4273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1544') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1544' zijn. (string(@Item)=('1544') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70431') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70431' zijn. (string(@Table)=('HL70431') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Recreational Drug Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Recreational Drug Use Code' zijn. (string(@LongName)=('Recreational Drug Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.1"
                 priority="4271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.2"
                 priority="4270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.3"
                 priority="4269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.4"
                 priority="4267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.5"
                 priority="4266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.6"
                 priority="4265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40"
                 priority="4263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1545') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1545' zijn. (string(@Item)=('1545') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70432') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70432' zijn. (string(@Table)=('HL70432') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admission Level of Care Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Admission Level of Care Code' zijn. (string(@LongName)=('Admission Level of Care Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.1"
                 priority="4261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.2"
                 priority="4260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.3"
                 priority="4259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.4"
                 priority="4257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.5"
                 priority="4256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.6"
                 priority="4255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41"
                 priority="4253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1546') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1546' zijn. (string(@Item)=('1546') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70433') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70433' zijn. (string(@Table)=('HL70433') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Precaution Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Precaution Code' zijn. (string(@LongName)=('Precaution Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.1"
                 priority="4251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.2"
                 priority="4250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.3"
                 priority="4249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.4"
                 priority="4247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.5"
                 priority="4246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.6"
                 priority="4245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42"
                 priority="4243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1547') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1547' zijn. (string(@Item)=('1547') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70434') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70434' zijn. (string(@Table)=('HL70434') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Condition Code' zijn. (string(@LongName)=('Patient Condition Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.1"
                 priority="4241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.2"
                 priority="4240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.3"
                 priority="4239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.4"
                 priority="4237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.5"
                 priority="4236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.6"
                 priority="4235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.43"
                 priority="4233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '759' zijn. (string(@Item)=('759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70315' zijn. (string(@Table)=('HL70315') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Living Will Code' zijn. (string(@LongName)=('Living Will Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.44"
                 priority="4232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '760' zijn. (string(@Item)=('760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70316' zijn. (string(@Table)=('HL70316') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Organ Donor Code' zijn. (string(@LongName)=('Organ Donor Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45"
                 priority="4231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1548') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1548' zijn. (string(@Item)=('1548') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70435' zijn. (string(@Table)=('HL70435') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Advance Directive Code' zijn. (string(@LongName)=('Advance Directive Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.1"
                 priority="4229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.2"
                 priority="4228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.3"
                 priority="4227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.4"
                 priority="4225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.5"
                 priority="4224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.6"
                 priority="4223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.46"
                 priority="4221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1549') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1549' zijn. (string(@Item)=('1549') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Status Effective Date' zijn. (string(@LongName)=('Patient Status Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.47"
                 priority="4220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1550') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1550' zijn. (string(@Item)=('1550') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected LOA Return Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected LOA Return Date/Time' zijn. (string(@LongName)=('Expected LOA Return Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.1"
                 priority="4218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.2"
                 priority="4217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.48"
                 priority="4215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1841') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1841' zijn. (string(@Item)=('1841') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Pre-admission Testing Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Pre-admission Testing Date/Time' zijn. (string(@LongName)=('Expected Pre-admission Testing Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.1"
                 priority="4213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.2"
                 priority="4212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.VISIT/hl7v2:PV2/hl7v2:PV2.49"
                 priority="4210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1842') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1842' zijn. (string(@Item)=('1842') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70534') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70534' zijn. (string(@Table)=('HL70534') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Notify Clergy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Notify Clergy Code' zijn. (string(@LongName)=('Notify Clergy Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e9855-false-d846902e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN"
                 priority="4209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:SPM is required [min 1x]. (count(hl7v2:SPM)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:SPM komt te vaak voor [max 1x]. (count(hl7v2:SPM)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.ORDER)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.ORDER is required [min 1x]. (count(hl7v2:OUL_R22.ORDER)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM"
                 priority="4208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.1 komt te vaak voor [max 1x]. (count(hl7v2:SPM.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.2 is required [min 1x]. (count(hl7v2:SPM.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.2 komt te vaak voor [max 1x]. (count(hl7v2:SPM.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.4 is required [min 1x]. (count(hl7v2:SPM.4)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.4 komt te vaak voor [max 1x]. (count(hl7v2:SPM.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.7 komt te vaak voor [max 1x]. (count(hl7v2:SPM.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.8 komt te vaak voor [max 1x]. (count(hl7v2:SPM.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.10 komt te vaak voor [max 1x]. (count(hl7v2:SPM.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.12 komt te vaak voor [max 1x]. (count(hl7v2:SPM.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.13 komt te vaak voor [max 1x]. (count(hl7v2:SPM.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.17 komt te vaak voor [max 1x]. (count(hl7v2:SPM.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.18 komt te vaak voor [max 1x]. (count(hl7v2:SPM.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.19 komt te vaak voor [max 1x]. (count(hl7v2:SPM.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.20 komt te vaak voor [max 1x]. (count(hl7v2:SPM.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.22 komt te vaak voor [max 1x]. (count(hl7v2:SPM.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.23 komt te vaak voor [max 1x]. (count(hl7v2:SPM.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.25 komt te vaak voor [max 1x]. (count(hl7v2:SPM.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.26 komt te vaak voor [max 1x]. (count(hl7v2:SPM.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.27 komt te vaak voor [max 1x]. (count(hl7v2:SPM.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.28 komt te vaak voor [max 1x]. (count(hl7v2:SPM.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): element hl7v2:SPM.29 komt te vaak voor [max 1x]. (count(hl7v2:SPM.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.1"
                 priority="4207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1754') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1754' zijn. (string(@Item)=('1754') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID _ SPM') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Set ID _ SPM' zijn. (string(@LongName)=('Set ID _ SPM') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2"
                 priority="4206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1755' zijn. (string(@Item)=('1755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'EIP' zijn. (string(@Type)=('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen ID' zijn. (string(@LongName)=('Specimen ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1"
                 priority="4204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn. (string(@LongName)=('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="4202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="4201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="4200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="4199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2"
                 priority="4197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn. (string(@LongName)=('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="4195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="4194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="4193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="4192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3"
                 priority="4190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1756') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1756' zijn. (string(@Item)=('1756') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'EIP' zijn. (string(@Type)=('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Parent IDs') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Parent IDs' zijn. (string(@LongName)=('Specimen Parent IDs') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1"
                 priority="4188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn. (string(@LongName)=('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="4186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="4185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="4184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="4183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2"
                 priority="4181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn. (string(@LongName)=('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="4179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="4178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="4177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="4176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4"
                 priority="4174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1900') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1900' zijn. (string(@Item)=('1900') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70487') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70487' zijn. (string(@Table)=('HL70487') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Type' zijn. (string(@LongName)=('Specimen Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.1"
                 priority="4172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.2"
                 priority="4171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.3"
                 priority="4170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.4"
                 priority="4168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.5"
                 priority="4167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.6"
                 priority="4166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.7"
                 priority="4164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.8"
                 priority="4163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.9"
                 priority="4162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5"
                 priority="4161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1757') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1757' zijn. (string(@Item)=('1757') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70541') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70541' zijn. (string(@Table)=('HL70541') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Type Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Type Modifier' zijn. (string(@LongName)=('Specimen Type Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.1"
                 priority="4159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.2"
                 priority="4158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.3"
                 priority="4157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.4"
                 priority="4155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.5"
                 priority="4154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.6"
                 priority="4153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.7"
                 priority="4151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.8"
                 priority="4150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.9"
                 priority="4149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6"
                 priority="4148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1758') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1758' zijn. (string(@Item)=('1758') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70371' zijn. (string(@Table)=('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Additives' zijn. (string(@LongName)=('Specimen Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.1"
                 priority="4146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.2"
                 priority="4145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.3"
                 priority="4144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.4"
                 priority="4142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.5"
                 priority="4141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.6"
                 priority="4140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.7"
                 priority="4138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.8"
                 priority="4137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.9"
                 priority="4136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7"
                 priority="4135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1759' zijn. (string(@Item)=('1759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70488') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70488' zijn. (string(@Table)=('HL70488') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Collection Method' zijn. (string(@LongName)=('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.1"
                 priority="4133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.2"
                 priority="4132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.3"
                 priority="4131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.4"
                 priority="4129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.5"
                 priority="4128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.6"
                 priority="4127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.7"
                 priority="4125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.8"
                 priority="4124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.9"
                 priority="4123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8"
                 priority="4122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1901') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1901' zijn. (string(@Item)=('1901') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Source Site' zijn. (string(@LongName)=('Specimen Source Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.1"
                 priority="4120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.2"
                 priority="4119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.3"
                 priority="4118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.4"
                 priority="4116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.5"
                 priority="4115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.6"
                 priority="4114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.7"
                 priority="4112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.8"
                 priority="4111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.9"
                 priority="4110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9"
                 priority="4109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1760' zijn. (string(@Item)=('1760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70542') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70542' zijn. (string(@Table)=('HL70542') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Source Site Modifier' zijn. (string(@LongName)=('Specimen Source Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.1"
                 priority="4107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.2"
                 priority="4106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.3"
                 priority="4105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.4"
                 priority="4103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.5"
                 priority="4102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.6"
                 priority="4101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.7"
                 priority="4099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.8"
                 priority="4098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.9"
                 priority="4097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10"
                 priority="4096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1761') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1761' zijn. (string(@Item)=('1761') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70543') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70543' zijn. (string(@Table)=('HL70543') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Collection Site' zijn. (string(@LongName)=('Specimen Collection Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.1"
                 priority="4094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.2"
                 priority="4093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.3"
                 priority="4092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.4"
                 priority="4090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.5"
                 priority="4089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.6"
                 priority="4088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.7"
                 priority="4086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.8"
                 priority="4085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.9"
                 priority="4084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11"
                 priority="4083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1762') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1762' zijn. (string(@Item)=('1762') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70369' zijn. (string(@Table)=('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Role' zijn. (string(@LongName)=('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.1"
                 priority="4081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.2"
                 priority="4080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.3"
                 priority="4079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.4"
                 priority="4077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.5"
                 priority="4076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.6"
                 priority="4075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.7"
                 priority="4073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.8"
                 priority="4072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.9"
                 priority="4071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12"
                 priority="4070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1902') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1902' zijn. (string(@Item)=('1902') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Collection Amount' zijn. (string(@LongName)=('Specimen Collection Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.1"
                 priority="4068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2"
                 priority="4067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="4065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="4064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="4063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="4061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="4060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="4059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.13"
                 priority="4057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1763') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1763' zijn. (string(@Item)=('1763') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Grouped Specimen Count') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Grouped Specimen Count' zijn. (string(@LongName)=('Grouped Specimen Count') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.14"
                 priority="4056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1764') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1764' zijn. (string(@Item)=('1764') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Description' zijn. (string(@LongName)=('Specimen Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15"
                 priority="4055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1908') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1908' zijn. (string(@Item)=('1908') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70376' zijn. (string(@Table)=('HL70376') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Handling Code' zijn. (string(@LongName)=('Specimen Handling Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.1"
                 priority="4053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.2"
                 priority="4052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.3"
                 priority="4051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.4"
                 priority="4049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.5"
                 priority="4048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.6"
                 priority="4047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.7"
                 priority="4045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.8"
                 priority="4044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.9"
                 priority="4043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16"
                 priority="4042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1903') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1903' zijn. (string(@Item)=('1903') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70489') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70489' zijn. (string(@Table)=('HL70489') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Risk Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Risk Code' zijn. (string(@LongName)=('Specimen Risk Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.1"
                 priority="4040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.2"
                 priority="4039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.3"
                 priority="4038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.4"
                 priority="4036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.5"
                 priority="4035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.6"
                 priority="4034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.7"
                 priority="4032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.8"
                 priority="4031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.9"
                 priority="4030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17"
                 priority="4029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1765') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1765' zijn. (string(@Item)=('1765') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Collection Date/Time' zijn. (string(@LongName)=('Specimen Collection Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1"
                 priority="4027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2"
                 priority="4022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18"
                 priority="4017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('248') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '248' zijn. (string(@Item)=('248') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Received Date/Time' zijn. (string(@LongName)=('Specimen Received Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.1"
                 priority="4015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.2"
                 priority="4014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19"
                 priority="4012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1904') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1904' zijn. (string(@Item)=('1904') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Expiration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Expiration Date/Time' zijn. (string(@LongName)=('Specimen Expiration Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.1"
                 priority="4010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.2"
                 priority="4009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.20"
                 priority="4007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1766') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1766' zijn. (string(@Item)=('1766') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Availability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Availability' zijn. (string(@LongName)=('Specimen Availability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21"
                 priority="4005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1767') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1767' zijn. (string(@Item)=('1767') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70490') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70490' zijn. (string(@Table)=('HL70490') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Reject Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Reject Reason' zijn. (string(@LongName)=('Specimen Reject Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.1"
                 priority="4003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.2"
                 priority="4002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.3"
                 priority="4001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.4"
                 priority="3999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.5"
                 priority="3998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.6"
                 priority="3997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.7"
                 priority="3995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.8"
                 priority="3994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.9"
                 priority="3993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22"
                 priority="3992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1768') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1768' zijn. (string(@Item)=('1768') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70491') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70491' zijn. (string(@Table)=('HL70491') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Quality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Quality' zijn. (string(@LongName)=('Specimen Quality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.1"
                 priority="3990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.2"
                 priority="3989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.3"
                 priority="3988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.4"
                 priority="3986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.5"
                 priority="3985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.6"
                 priority="3984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.7"
                 priority="3982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.8"
                 priority="3981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.9"
                 priority="3980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23"
                 priority="3979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1769') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1769' zijn. (string(@Item)=('1769') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70492') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70492' zijn. (string(@Table)=('HL70492') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Appropriateness') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Appropriateness' zijn. (string(@LongName)=('Specimen Appropriateness') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.1"
                 priority="3977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.2"
                 priority="3976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.3"
                 priority="3975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.4"
                 priority="3973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.5"
                 priority="3972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.6"
                 priority="3971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.7"
                 priority="3969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.8"
                 priority="3968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.9"
                 priority="3967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24"
                 priority="3966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1770') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1770' zijn. (string(@Item)=('1770') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70493') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70493' zijn. (string(@Table)=('HL70493') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Condition' zijn. (string(@LongName)=('Specimen Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.1"
                 priority="3964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.2"
                 priority="3963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.3"
                 priority="3962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.4"
                 priority="3960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.5"
                 priority="3959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.6"
                 priority="3958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.7"
                 priority="3956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.8"
                 priority="3955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.9"
                 priority="3954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25"
                 priority="3953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1771') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1771' zijn. (string(@Item)=('1771') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Current Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Current Quantity' zijn. (string(@LongName)=('Specimen Current Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.1"
                 priority="3951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2"
                 priority="3950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.26"
                 priority="3940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1772') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1772' zijn. (string(@Item)=('1772') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Number of Specimen Containers') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Number of Specimen Containers' zijn. (string(@LongName)=('Number of Specimen Containers') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27"
                 priority="3939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1773') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1773' zijn. (string(@Item)=('1773') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Container Type' zijn. (string(@LongName)=('Container Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.1"
                 priority="3937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.2"
                 priority="3936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.3"
                 priority="3935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.4"
                 priority="3933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.5"
                 priority="3932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.6"
                 priority="3931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.7"
                 priority="3929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.8"
                 priority="3928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.9"
                 priority="3927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28"
                 priority="3926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1774') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1774' zijn. (string(@Item)=('1774') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70544') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70544' zijn. (string(@Table)=('HL70544') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Container Condition' zijn. (string(@LongName)=('Container Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.1"
                 priority="3924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.2"
                 priority="3923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.3"
                 priority="3922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.4"
                 priority="3920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.5"
                 priority="3919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.6"
                 priority="3918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.7"
                 priority="3916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.8"
                 priority="3915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.9"
                 priority="3914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29"
                 priority="3913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1775') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Item MOET '1775' zijn. (string(@Item)=('1775') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70494') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70494' zijn. (string(@Table)=('HL70494') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Child Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Child Role' zijn. (string(@LongName)=('Specimen Child Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.43-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.1"
                 priority="3911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.2"
                 priority="3910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.3"
                 priority="3909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.4"
                 priority="3907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.5"
                 priority="3906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.6"
                 priority="3905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.7"
                 priority="3903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.8"
                 priority="3902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.9"
                 priority="3901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX"
                 priority="3900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.1"
                 priority="3899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.2"
                 priority="3898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3"
                 priority="3896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="3894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="3893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="3892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="3890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="3889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="3888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.4"
                 priority="3886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5"
                 priority="3885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6"
                 priority="3884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="3882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="3881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="3880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="3878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="3877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="3876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.7"
                 priority="3874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.8"
                 priority="3873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.9"
                 priority="3872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.10"
                 priority="3871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.11"
                 priority="3869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12"
                 priority="3867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="3865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="3864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.13"
                 priority="3862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14"
                 priority="3861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="3859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="3858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15"
                 priority="3856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="3854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="3853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="3852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="3850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="3849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="3848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16"
                 priority="3846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="3844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="3843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="3836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="3835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="3834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="3833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="3832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="3831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="3830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="3824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="3822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="3821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="3819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="3817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="3811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="3809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="3799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="3787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="3785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="3780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="3775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="3774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="3761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17"
                 priority="3748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="3746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="3745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="3744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="3742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="3741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="3740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18"
                 priority="3738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="3736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="3735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="3734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="3733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19"
                 priority="3731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="3729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="3728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e9867-false-d858844e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER"
                 priority="3726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:SAC is required [min 1x]. (count(hl7v2:SAC)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:SAC komt te vaak voor [max 1x]. (count(hl7v2:SAC)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:INV komt te vaak voor [max 1x]. (count(hl7v2:INV)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC"
                 priority="3725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.1 komt te vaak voor [max 1x]. (count(hl7v2:SAC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.2 komt te vaak voor [max 1x]. (count(hl7v2:SAC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.3 komt te vaak voor [max 1x]. (count(hl7v2:SAC.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.4 komt te vaak voor [max 1x]. (count(hl7v2:SAC.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.5 komt te vaak voor [max 1x]. (count(hl7v2:SAC.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.6 komt te vaak voor [max 1x]. (count(hl7v2:SAC.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.7 komt te vaak voor [max 1x]. (count(hl7v2:SAC.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.8 komt te vaak voor [max 1x]. (count(hl7v2:SAC.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.9 komt te vaak voor [max 1x]. (count(hl7v2:SAC.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.10 komt te vaak voor [max 1x]. (count(hl7v2:SAC.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.11 komt te vaak voor [max 1x]. (count(hl7v2:SAC.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.12 komt te vaak voor [max 1x]. (count(hl7v2:SAC.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.13 komt te vaak voor [max 1x]. (count(hl7v2:SAC.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.14 komt te vaak voor [max 1x]. (count(hl7v2:SAC.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.16 komt te vaak voor [max 1x]. (count(hl7v2:SAC.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.17 komt te vaak voor [max 1x]. (count(hl7v2:SAC.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.18 komt te vaak voor [max 1x]. (count(hl7v2:SAC.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.19 komt te vaak voor [max 1x]. (count(hl7v2:SAC.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.20 komt te vaak voor [max 1x]. (count(hl7v2:SAC.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.21 komt te vaak voor [max 1x]. (count(hl7v2:SAC.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.22 komt te vaak voor [max 1x]. (count(hl7v2:SAC.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.23 komt te vaak voor [max 1x]. (count(hl7v2:SAC.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.24 komt te vaak voor [max 1x]. (count(hl7v2:SAC.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.25 komt te vaak voor [max 1x]. (count(hl7v2:SAC.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.26 komt te vaak voor [max 1x]. (count(hl7v2:SAC.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.28 komt te vaak voor [max 1x]. (count(hl7v2:SAC.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.29 komt te vaak voor [max 1x]. (count(hl7v2:SAC.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.30 komt te vaak voor [max 1x]. (count(hl7v2:SAC.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.31 komt te vaak voor [max 1x]. (count(hl7v2:SAC.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.32 komt te vaak voor [max 1x]. (count(hl7v2:SAC.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.33 komt te vaak voor [max 1x]. (count(hl7v2:SAC.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.34 komt te vaak voor [max 1x]. (count(hl7v2:SAC.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.35 komt te vaak voor [max 1x]. (count(hl7v2:SAC.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.36 komt te vaak voor [max 1x]. (count(hl7v2:SAC.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.37 komt te vaak voor [max 1x]. (count(hl7v2:SAC.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.38 komt te vaak voor [max 1x]. (count(hl7v2:SAC.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.39)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.39 komt te vaak voor [max 1x]. (count(hl7v2:SAC.39)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.42 komt te vaak voor [max 1x]. (count(hl7v2:SAC.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1"
                 priority="3724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1329') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1329' zijn. (string(@Item)=('1329') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('External Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'External Accession Identifier' zijn. (string(@LongName)=('External Accession Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.1"
                 priority="3722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.2"
                 priority="3721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.3"
                 priority="3720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.4"
                 priority="3719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2"
                 priority="3717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1330') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1330' zijn. (string(@Item)=('1330') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Accession Identifier' zijn. (string(@LongName)=('Accession Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.1"
                 priority="3715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.2"
                 priority="3714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.3"
                 priority="3713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.4"
                 priority="3712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3"
                 priority="3710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1331') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1331' zijn. (string(@Item)=('1331') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Identifier' zijn. (string(@LongName)=('Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.1"
                 priority="3708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.2"
                 priority="3707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.3"
                 priority="3706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.4"
                 priority="3705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4"
                 priority="3703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1332') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1332' zijn. (string(@Item)=('1332') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Primary (parent) Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Primary (parent) Container Identifier' zijn. (string(@LongName)=('Primary (parent) Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.1"
                 priority="3701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.2"
                 priority="3700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.3"
                 priority="3699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.4"
                 priority="3698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5"
                 priority="3696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1333') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1333' zijn. (string(@Item)=('1333') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Equipment Container Identifier' zijn. (string(@LongName)=('Equipment Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.1"
                 priority="3694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.2"
                 priority="3693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.3"
                 priority="3692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.4"
                 priority="3691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6"
                 priority="3689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x]. (count(hl7v2:SPS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x]. (count(hl7v2:SPS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x]. (count(hl7v2:SPS.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x]. (count(hl7v2:SPS.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x]. (count(hl7v2:SPS.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x]. (count(hl7v2:SPS.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x]. (count(hl7v2:SPS.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('249') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '249' zijn. (string(@Item)=('249') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'SPS' zijn. (string(@Type)=('SPS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Specimen Source' zijn. (string(@LongName)=('Specimen Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1"
                 priority="3687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Source Name or Code' zijn. (string(@LongName)=('Specimen Source Name or Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="3685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="3684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="3683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="3681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="3680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="3679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="3677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="3676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="3675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2"
                 priority="3674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70371' zijn. (string(@Table)=('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Additives' zijn. (string(@LongName)=('Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="3672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="3671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="3670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="3668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="3667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="3666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="3664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="3663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="3662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3"
                 priority="3661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Collection Method' zijn. (string(@LongName)=('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape"
                 priority="3660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="3659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="3658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4"
                 priority="3657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70163' zijn. (string(@Table)=('HL70163') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Body Site' zijn. (string(@LongName)=('Body Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="3655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="3654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="3653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="3651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="3650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="3649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="3647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="3646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="3645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5"
                 priority="3644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70495' zijn. (string(@Table)=('HL70495') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Site Modifier' zijn. (string(@LongName)=('Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="3642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="3641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="3640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="3638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="3637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="3636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="3634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="3633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="3632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6"
                 priority="3631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Collection Method Modifier Code' zijn. (string(@LongName)=('Collection Method Modifier Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="3629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="3628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="3627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="3625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="3624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="3623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="3621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="3620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="3619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7"
                 priority="3618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70369' zijn. (string(@Table)=('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Role' zijn. (string(@LongName)=('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="3616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="3615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="3614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="3612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="3611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="3610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="3608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="3607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="3606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.7"
                 priority="3605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1334') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1334' zijn. (string(@Item)=('1334') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Registration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Registration Date/Time' zijn. (string(@LongName)=('Registration Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.1"
                 priority="3603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.2"
                 priority="3602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8"
                 priority="3600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1335') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1335' zijn. (string(@Item)=('1335') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70370') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70370' zijn. (string(@Table)=('HL70370') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Status' zijn. (string(@LongName)=('Container Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.1"
                 priority="3598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.2"
                 priority="3597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.3"
                 priority="3596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.4"
                 priority="3594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.5"
                 priority="3593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.6"
                 priority="3592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9"
                 priority="3590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1336') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1336' zijn. (string(@Item)=('1336') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70378') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70378' zijn. (string(@Table)=('HL70378') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Carrier Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Carrier Type' zijn. (string(@LongName)=('Carrier Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.1"
                 priority="3588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.2"
                 priority="3587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.3"
                 priority="3586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.4"
                 priority="3584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.5"
                 priority="3583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.6"
                 priority="3582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10"
                 priority="3580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1337') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1337' zijn. (string(@Item)=('1337') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Carrier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Carrier Identifier' zijn. (string(@LongName)=('Carrier Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.1"
                 priority="3578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.2"
                 priority="3577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.3"
                 priority="3576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.4"
                 priority="3575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11"
                 priority="3573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer (*[matches(local-name(),'^NA\.\d+$')] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric (*[. castable as xs:decimal] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 is required [min 1x]. (count(hl7v2:NA.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x]. (count(hl7v2:NA.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x]. (count(hl7v2:NA.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x]. (count(hl7v2:NA.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x]. (count(hl7v2:NA.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1338') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1338' zijn. (string(@Item)=('1338') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NA') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NA' zijn. (string(@Type)=('NA') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Position in Carrier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Position in Carrier' zijn. (string(@LongName)=('Position in Carrier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.1"
                 priority="3571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value1' zijn. (string(@LongName)=('Value1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.2"
                 priority="3570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value2' zijn. (string(@LongName)=('Value2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.3"
                 priority="3569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value3' zijn. (string(@LongName)=('Value3') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.4"
                 priority="3568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value4' zijn. (string(@LongName)=('Value4') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12"
                 priority="3567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1339') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1339' zijn. (string(@Item)=('1339') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70379') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70379' zijn. (string(@Table)=('HL70379') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Tray Type - SAC') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Tray Type - SAC' zijn. (string(@LongName)=('Tray Type - SAC') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.1"
                 priority="3565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.2"
                 priority="3564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.3"
                 priority="3563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.4"
                 priority="3561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.5"
                 priority="3560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.6"
                 priority="3559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13"
                 priority="3557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1340') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1340' zijn. (string(@Item)=('1340') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Tray Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Tray Identifier' zijn. (string(@LongName)=('Tray Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.1"
                 priority="3555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.2"
                 priority="3554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.3"
                 priority="3553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.4"
                 priority="3552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14"
                 priority="3550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer (*[matches(local-name(),'^NA\.\d+$')] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric (*[. castable as xs:decimal] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 is required [min 1x]. (count(hl7v2:NA.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x]. (count(hl7v2:NA.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x]. (count(hl7v2:NA.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x]. (count(hl7v2:NA.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x]. (count(hl7v2:NA.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1341') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1341' zijn. (string(@Item)=('1341') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NA') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NA' zijn. (string(@Type)=('NA') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Position in Tray') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Position in Tray' zijn. (string(@LongName)=('Position in Tray') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.1"
                 priority="3548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value1' zijn. (string(@LongName)=('Value1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.2"
                 priority="3547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value2' zijn. (string(@LongName)=('Value2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.3"
                 priority="3546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value3' zijn. (string(@LongName)=('Value3') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.4"
                 priority="3545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value4' zijn. (string(@LongName)=('Value4') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15"
                 priority="3544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1342') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1342' zijn. (string(@Item)=('1342') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Location' zijn. (string(@LongName)=('Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.1"
                 priority="3542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.2"
                 priority="3541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.3"
                 priority="3540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.4"
                 priority="3538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.5"
                 priority="3537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.6"
                 priority="3536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.16"
                 priority="3534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1343') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1343' zijn. (string(@Item)=('1343') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Height') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Height' zijn. (string(@LongName)=('Container Height') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.17"
                 priority="3533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1344') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1344' zijn. (string(@Item)=('1344') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Diameter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Diameter' zijn. (string(@LongName)=('Container Diameter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.18"
                 priority="3532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1345') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1345' zijn. (string(@Item)=('1345') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Barrier Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Barrier Delta' zijn. (string(@LongName)=('Barrier Delta') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.19"
                 priority="3531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1346') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1346' zijn. (string(@Item)=('1346') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bottom Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Bottom Delta' zijn. (string(@LongName)=('Bottom Delta') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20"
                 priority="3530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1347') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1347' zijn. (string(@Item)=('1347') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Height/Diameter/Delta Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Height/Diameter/Delta Units' zijn. (string(@LongName)=('Container Height/Diameter/Delta Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.1"
                 priority="3528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.2"
                 priority="3527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.3"
                 priority="3526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.4"
                 priority="3524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.5"
                 priority="3523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.6"
                 priority="3522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.21"
                 priority="3520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('644') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '644' zijn. (string(@Item)=('644') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Volume' zijn. (string(@LongName)=('Container Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.22"
                 priority="3519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1349') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1349' zijn. (string(@Item)=('1349') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Available Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Available Specimen Volume' zijn. (string(@LongName)=('Available Specimen Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.23"
                 priority="3518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1350') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1350' zijn. (string(@Item)=('1350') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Initial Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Initial Specimen Volume' zijn. (string(@LongName)=('Initial Specimen Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24"
                 priority="3517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1351') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1351' zijn. (string(@Item)=('1351') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Volume Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Volume Units' zijn. (string(@LongName)=('Volume Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.1"
                 priority="3515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.2"
                 priority="3514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.3"
                 priority="3513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.4"
                 priority="3511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.5"
                 priority="3510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.6"
                 priority="3509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25"
                 priority="3507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1352') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1352' zijn. (string(@Item)=('1352') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70380') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70380' zijn. (string(@Table)=('HL70380') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Separator Type' zijn. (string(@LongName)=('Separator Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.1"
                 priority="3505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.2"
                 priority="3504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.3"
                 priority="3503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.4"
                 priority="3501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.5"
                 priority="3500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.6"
                 priority="3499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26"
                 priority="3497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1353') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1353' zijn. (string(@Item)=('1353') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70381') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70381' zijn. (string(@Table)=('HL70381') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cap Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Cap Type' zijn. (string(@LongName)=('Cap Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.1"
                 priority="3495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.2"
                 priority="3494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.3"
                 priority="3493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.4"
                 priority="3491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.5"
                 priority="3490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.6"
                 priority="3489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27"
                 priority="3487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('647') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '647' zijn. (string(@Item)=('647') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70371' zijn. (string(@Table)=('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Additive') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Additive' zijn. (string(@LongName)=('Additive') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.1"
                 priority="3485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.2"
                 priority="3484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.3"
                 priority="3483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.4"
                 priority="3481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.5"
                 priority="3480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.6"
                 priority="3479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.7"
                 priority="3477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.8"
                 priority="3476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.9"
                 priority="3475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28"
                 priority="3474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1355') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1355' zijn. (string(@Item)=('1355') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Component') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Specimen Component' zijn. (string(@LongName)=('Specimen Component') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.1"
                 priority="3472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.2"
                 priority="3471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.3"
                 priority="3470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.4"
                 priority="3468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.5"
                 priority="3467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.6"
                 priority="3466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29"
                 priority="3464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1356') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1356' zijn. (string(@Item)=('1356') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Dilution Factor' zijn. (string(@LongName)=('Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.1"
                 priority="3462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.2"
                 priority="3461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.3"
                 priority="3460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.4"
                 priority="3459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30"
                 priority="3458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1357') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1357' zijn. (string(@Item)=('1357') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70373') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70373' zijn. (string(@Table)=('HL70373') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Treatment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Treatment' zijn. (string(@LongName)=('Treatment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.1"
                 priority="3456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.2"
                 priority="3455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.3"
                 priority="3454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.4"
                 priority="3452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.5"
                 priority="3451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.6"
                 priority="3450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31"
                 priority="3448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1358') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1358' zijn. (string(@Item)=('1358') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Temperature') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Temperature' zijn. (string(@LongName)=('Temperature') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.1"
                 priority="3446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.2"
                 priority="3445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.3"
                 priority="3444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.4"
                 priority="3443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.32"
                 priority="3442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1359') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1359' zijn. (string(@Item)=('1359') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Hemolysis Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Hemolysis Index' zijn. (string(@LongName)=('Hemolysis Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33"
                 priority="3441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1360') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1360' zijn. (string(@Item)=('1360') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Hemolysis Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Hemolysis Index Units' zijn. (string(@LongName)=('Hemolysis Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.1"
                 priority="3439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.2"
                 priority="3438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.3"
                 priority="3437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.4"
                 priority="3435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.5"
                 priority="3434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.6"
                 priority="3433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.34"
                 priority="3431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1361') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1361' zijn. (string(@Item)=('1361') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Lipemia Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Lipemia Index' zijn. (string(@LongName)=('Lipemia Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35"
                 priority="3430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1362') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1362' zijn. (string(@Item)=('1362') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Lipemia Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Lipemia Index Units' zijn. (string(@LongName)=('Lipemia Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.1"
                 priority="3428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.2"
                 priority="3427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.3"
                 priority="3426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.4"
                 priority="3424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.5"
                 priority="3423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.6"
                 priority="3422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.36"
                 priority="3420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1363') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1363' zijn. (string(@Item)=('1363') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Icterus Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Icterus Index' zijn. (string(@LongName)=('Icterus Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37"
                 priority="3419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1364') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1364' zijn. (string(@Item)=('1364') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Icterus Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Icterus Index Units' zijn. (string(@LongName)=('Icterus Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.1"
                 priority="3417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.2"
                 priority="3416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.3"
                 priority="3415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.4"
                 priority="3413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.5"
                 priority="3412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.6"
                 priority="3411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.38"
                 priority="3409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1365') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1365' zijn. (string(@Item)=('1365') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Fibrin Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Fibrin Index' zijn. (string(@LongName)=('Fibrin Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39"
                 priority="3408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1366') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1366' zijn. (string(@Item)=('1366') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Fibrin Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Fibrin Index Units' zijn. (string(@LongName)=('Fibrin Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.1"
                 priority="3406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.2"
                 priority="3405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.3"
                 priority="3404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.4"
                 priority="3402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.5"
                 priority="3401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.6"
                 priority="3400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40"
                 priority="3398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1367') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1367' zijn. (string(@Item)=('1367') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70374') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70374' zijn. (string(@Table)=('HL70374') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('System Induced Contaminants') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'System Induced Contaminants' zijn. (string(@LongName)=('System Induced Contaminants') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.1"
                 priority="3396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.2"
                 priority="3395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.3"
                 priority="3394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.4"
                 priority="3392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.5"
                 priority="3391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.6"
                 priority="3390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41"
                 priority="3388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1368') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1368' zijn. (string(@Item)=('1368') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70382') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70382' zijn. (string(@Table)=('HL70382') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Drug Interference') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Drug Interference' zijn. (string(@LongName)=('Drug Interference') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.1"
                 priority="3386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.2"
                 priority="3385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.3"
                 priority="3384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.4"
                 priority="3382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.5"
                 priority="3381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.6"
                 priority="3380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42"
                 priority="3378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1369') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1369' zijn. (string(@Item)=('1369') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70375') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70375' zijn. (string(@Table)=('HL70375') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Artificial Blood') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Artificial Blood' zijn. (string(@LongName)=('Artificial Blood') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.1"
                 priority="3376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.2"
                 priority="3375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.3"
                 priority="3374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.4"
                 priority="3372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.5"
                 priority="3371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.6"
                 priority="3370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43"
                 priority="3368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1370') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1370' zijn. (string(@Item)=('1370') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70376' zijn. (string(@Table)=('HL70376') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Special Handling Code' zijn. (string(@LongName)=('Special Handling Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.1"
                 priority="3366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.2"
                 priority="3365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.3"
                 priority="3364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.4"
                 priority="3362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.5"
                 priority="3361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.6"
                 priority="3360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.7"
                 priority="3358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.8"
                 priority="3357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.9"
                 priority="3356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44"
                 priority="3355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1371') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1371' zijn. (string(@Item)=('1371') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70377') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70377' zijn. (string(@Table)=('HL70377') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Environmental Factors') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Other Environmental Factors' zijn. (string(@LongName)=('Other Environmental Factors') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.1"
                 priority="3353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.2"
                 priority="3352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.3"
                 priority="3351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.4"
                 priority="3349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.5"
                 priority="3348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.6"
                 priority="3347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV"
                 priority="3345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.1 is required [min 1x]. (count(hl7v2:INV.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.1 komt te vaak voor [max 1x]. (count(hl7v2:INV.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.2 is required [min 1x]. (count(hl7v2:INV.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.3 komt te vaak voor [max 1x]. (count(hl7v2:INV.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.4 komt te vaak voor [max 1x]. (count(hl7v2:INV.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.5 komt te vaak voor [max 1x]. (count(hl7v2:INV.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.6 komt te vaak voor [max 1x]. (count(hl7v2:INV.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.7 komt te vaak voor [max 1x]. (count(hl7v2:INV.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.8 komt te vaak voor [max 1x]. (count(hl7v2:INV.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.9 komt te vaak voor [max 1x]. (count(hl7v2:INV.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.10 komt te vaak voor [max 1x]. (count(hl7v2:INV.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.11 komt te vaak voor [max 1x]. (count(hl7v2:INV.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.12 komt te vaak voor [max 1x]. (count(hl7v2:INV.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.13 komt te vaak voor [max 1x]. (count(hl7v2:INV.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.14 komt te vaak voor [max 1x]. (count(hl7v2:INV.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.16 komt te vaak voor [max 1x]. (count(hl7v2:INV.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.17 komt te vaak voor [max 1x]. (count(hl7v2:INV.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.18 komt te vaak voor [max 1x]. (count(hl7v2:INV.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.19 komt te vaak voor [max 1x]. (count(hl7v2:INV.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:INV.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): element hl7v2:INV.20 komt te vaak voor [max 1x]. (count(hl7v2:INV.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1"
                 priority="3344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1372') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1372' zijn. (string(@Item)=('1372') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70451') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Table MOET 'HL70451' zijn. (string(@Table)=('HL70451') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Substance Identifier' zijn. (string(@LongName)=('Substance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.1"
                 priority="3342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.2"
                 priority="3341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.3"
                 priority="3340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.4"
                 priority="3338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.5"
                 priority="3337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.1/hl7v2:CE.6"
                 priority="3336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2"
                 priority="3334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1373') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1373' zijn. (string(@Item)=('1373') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70383') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Table MOET 'HL70383' zijn. (string(@Table)=('HL70383') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Substance Status' zijn. (string(@LongName)=('Substance Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.1"
                 priority="3332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.2"
                 priority="3331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.3"
                 priority="3330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.4"
                 priority="3328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.5"
                 priority="3327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.2/hl7v2:CE.6"
                 priority="3326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3"
                 priority="3324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1374') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1374' zijn. (string(@Item)=('1374') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70384') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Table MOET 'HL70384' zijn. (string(@Table)=('HL70384') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Substance Type' zijn. (string(@LongName)=('Substance Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.1"
                 priority="3322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.2"
                 priority="3321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.3"
                 priority="3320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.4"
                 priority="3318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.5"
                 priority="3317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.3/hl7v2:CE.6"
                 priority="3316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4"
                 priority="3314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1532') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1532' zijn. (string(@Item)=('1532') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Inventory Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Inventory Container Identifier' zijn. (string(@LongName)=('Inventory Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.1"
                 priority="3312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.2"
                 priority="3311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.3"
                 priority="3310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.4"
                 priority="3308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.5"
                 priority="3307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.4/hl7v2:CE.6"
                 priority="3306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5"
                 priority="3304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1376') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1376' zijn. (string(@Item)=('1376') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Carrier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Container Carrier Identifier' zijn. (string(@LongName)=('Container Carrier Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.1"
                 priority="3302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.2"
                 priority="3301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.3"
                 priority="3300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.4"
                 priority="3298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.5"
                 priority="3297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.5/hl7v2:CE.6"
                 priority="3296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6"
                 priority="3294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1377') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1377' zijn. (string(@Item)=('1377') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Position on Carrier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Position on Carrier' zijn. (string(@LongName)=('Position on Carrier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.1"
                 priority="3292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.2"
                 priority="3291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.3"
                 priority="3290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.4"
                 priority="3288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.5"
                 priority="3287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.6/hl7v2:CE.6"
                 priority="3286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.7"
                 priority="3284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1378') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1378' zijn. (string(@Item)=('1378') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Initial Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Initial Quantity' zijn. (string(@LongName)=('Initial Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.8"
                 priority="3283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1379') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1379' zijn. (string(@Item)=('1379') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Current Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Current Quantity' zijn. (string(@LongName)=('Current Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.9"
                 priority="3282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1380') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1380' zijn. (string(@Item)=('1380') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Available Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Available Quantity' zijn. (string(@LongName)=('Available Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.10"
                 priority="3281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1381') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1381' zijn. (string(@Item)=('1381') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Consumption Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Consumption Quantity' zijn. (string(@LongName)=('Consumption Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11"
                 priority="3280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1382') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1382' zijn. (string(@Item)=('1382') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Quantity Units' zijn. (string(@LongName)=('Quantity Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.1"
                 priority="3278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.2"
                 priority="3277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.3"
                 priority="3276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.4"
                 priority="3274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.5"
                 priority="3273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.11/hl7v2:CE.6"
                 priority="3272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.12"
                 priority="3270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1383') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1383' zijn. (string(@Item)=('1383') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Expiration Date/Time' zijn. (string(@LongName)=('Expiration Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.12/hl7v2:TS.1"
                 priority="3268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.12/hl7v2:TS.2"
                 priority="3267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.13"
                 priority="3265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1384') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1384' zijn. (string(@Item)=('1384') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('First Used Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'First Used Date/Time' zijn. (string(@LongName)=('First Used Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.13/hl7v2:TS.1"
                 priority="3263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.13/hl7v2:TS.2"
                 priority="3262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14"
                 priority="3260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1385') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1385' zijn. (string(@Item)=('1385') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'TQ' zijn. (string(@Type)=('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('On Board Stability Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'On Board Stability Duration' zijn. (string(@LongName)=('On Board Stability Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1"
                 priority="3258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="3256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="3255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.2"
                 priority="3245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'RI' zijn. (string(@Type)=('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Interval' zijn. (string(@LongName)=('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="3243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Repeat Pattern' zijn. (string(@LongName)=('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="3242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Explicit Time Interval' zijn. (string(@LongName)=('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.3"
                 priority="3241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Duration' zijn. (string(@LongName)=('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.4"
                 priority="3240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Start Date/Time' zijn. (string(@LongName)=('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="3238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="3237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.5"
                 priority="3235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'End Date/Time' zijn. (string(@LongName)=('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="3233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="3232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.6"
                 priority="3230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Priority' zijn. (string(@LongName)=('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.7"
                 priority="3229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Condition' zijn. (string(@LongName)=('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8"
                 priority="3228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape"
                 priority="3227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="3226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="3225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.9"
                 priority="3224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Table MOET 'HL70472' zijn. (string(@Table)=('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Conjunction' zijn. (string(@LongName)=('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10"
                 priority="3222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'OSD' zijn. (string(@Type)=('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Order Sequencing' zijn. (string(@LongName)=('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="3220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70524' zijn. (string(@Table)=('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence/Results Flag' zijn. (string(@LongName)=('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="3218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Entity Identifier' zijn. (string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="3217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Namespace ID' zijn. (string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="3216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Entity Identifier' zijn. (string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="3215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Namespace ID' zijn. (string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="3214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence Condition Value' zijn. (string(@LongName)=('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="3213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Maximum Number of Repeats' zijn. (string(@LongName)=('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="3212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID' zijn. (string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="3211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID Type' zijn. (string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="3209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID' zijn. (string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="3208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID Type' zijn. (string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11"
                 priority="3206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Occurrence Duration' zijn. (string(@LongName)=('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="3204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="3203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="3202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="3200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="3199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="3198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.14/hl7v2:TQ.12"
                 priority="3196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Total Occurrences' zijn. (string(@LongName)=('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15"
                 priority="3195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1386') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1386' zijn. (string(@Item)=('1386') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Test/Fluid Identifier(s)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Test/Fluid Identifier(s)' zijn. (string(@LongName)=('Test/Fluid Identifier(s)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.1"
                 priority="3193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.2"
                 priority="3192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.3"
                 priority="3191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.4"
                 priority="3189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.5"
                 priority="3188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.15/hl7v2:CE.6"
                 priority="3187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.16"
                 priority="3185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1387') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1387' zijn. (string(@Item)=('1387') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Manufacturer Lot Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Manufacturer Lot Number' zijn. (string(@LongName)=('Manufacturer Lot Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17"
                 priority="3184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('286') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '286' zijn. (string(@Item)=('286') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70385') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Table MOET 'HL70385' zijn. (string(@Table)=('HL70385') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Manufacturer Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Manufacturer Identifier' zijn. (string(@LongName)=('Manufacturer Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.1"
                 priority="3182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.2"
                 priority="3181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.3"
                 priority="3180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.4"
                 priority="3178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.5"
                 priority="3177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.17/hl7v2:CE.6"
                 priority="3176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18"
                 priority="3174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1389') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1389' zijn. (string(@Item)=('1389') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70386') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Table MOET 'HL70386' zijn. (string(@Table)=('HL70386') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Supplier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Supplier Identifier' zijn. (string(@LongName)=('Supplier Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.1"
                 priority="3172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.2"
                 priority="3171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.3"
                 priority="3170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.4"
                 priority="3168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.5"
                 priority="3167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.18/hl7v2:CE.6"
                 priority="3166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19"
                 priority="3164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1626') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1626' zijn. (string(@Item)=('1626') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('On Board Stability Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'On Board Stability Time' zijn. (string(@LongName)=('On Board Stability Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.1"
                 priority="3162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2"
                 priority="3161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.19/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20"
                 priority="3151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1896') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Item MOET '1896' zijn. (string(@Item)=('1896') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Target Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(INV_segment): de waarde van @LongName MOET 'Target Value' zijn. (string(@LongName)=('Target Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.1"
                 priority="3149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2"
                 priority="3148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.CONTAINER/hl7v2:INV/hl7v2:INV.20/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e9874-false-d873383e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER"
                 priority="3138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OBR is required [min 1x]. (count(hl7v2:OBR)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OBR komt te vaak voor [max 1x]. (count(hl7v2:OBR)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:ORC is required [min 1x]. (count(hl7v2:ORC)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:ORC komt te vaak voor [max 1x]. (count(hl7v2:ORC)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OUL_R22.RESULT)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OUL_R22.RESULT is required [min 1x]. (count(hl7v2:OUL_R22.RESULT)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR"
                 priority="3137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.1 komt te vaak voor [max 1x]. (count(hl7v2:OBR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.2 komt te vaak voor [max 1x]. (count(hl7v2:OBR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.3 is required [min 1x]. (count(hl7v2:OBR.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.3 komt te vaak voor [max 1x]. (count(hl7v2:OBR.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.4 is required [min 1x]. (count(hl7v2:OBR.4)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.4 komt te vaak voor [max 1x]. (count(hl7v2:OBR.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.5 komt te vaak voor [max 1x]. (count(hl7v2:OBR.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.6 komt te vaak voor [max 1x]. (count(hl7v2:OBR.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.7 komt te vaak voor [max 1x]. (count(hl7v2:OBR.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.8 komt te vaak voor [max 1x]. (count(hl7v2:OBR.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.9 komt te vaak voor [max 1x]. (count(hl7v2:OBR.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.11 komt te vaak voor [max 1x]. (count(hl7v2:OBR.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.12 komt te vaak voor [max 1x]. (count(hl7v2:OBR.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.13 komt te vaak voor [max 1x]. (count(hl7v2:OBR.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.14 komt te vaak voor [max 1x]. (count(hl7v2:OBR.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.15 komt te vaak voor [max 1x]. (count(hl7v2:OBR.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.18 komt te vaak voor [max 1x]. (count(hl7v2:OBR.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.19 komt te vaak voor [max 1x]. (count(hl7v2:OBR.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.20 komt te vaak voor [max 1x]. (count(hl7v2:OBR.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.21 komt te vaak voor [max 1x]. (count(hl7v2:OBR.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.22 komt te vaak voor [max 1x]. (count(hl7v2:OBR.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.23 komt te vaak voor [max 1x]. (count(hl7v2:OBR.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.24 komt te vaak voor [max 1x]. (count(hl7v2:OBR.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.25 komt te vaak voor [max 1x]. (count(hl7v2:OBR.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.26 komt te vaak voor [max 1x]. (count(hl7v2:OBR.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.29 komt te vaak voor [max 1x]. (count(hl7v2:OBR.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.30 komt te vaak voor [max 1x]. (count(hl7v2:OBR.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.32 komt te vaak voor [max 1x]. (count(hl7v2:OBR.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.36 komt te vaak voor [max 1x]. (count(hl7v2:OBR.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.37 komt te vaak voor [max 1x]. (count(hl7v2:OBR.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.40 komt te vaak voor [max 1x]. (count(hl7v2:OBR.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.41)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.41 komt te vaak voor [max 1x]. (count(hl7v2:OBR.41)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.42 komt te vaak voor [max 1x]. (count(hl7v2:OBR.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.44)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.44 komt te vaak voor [max 1x]. (count(hl7v2:OBR.44)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.48 komt te vaak voor [max 1x]. (count(hl7v2:OBR.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.49)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): element hl7v2:OBR.49 komt te vaak voor [max 1x]. (count(hl7v2:OBR.49)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.1"
                 priority="3136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('237') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '237' zijn. (string(@Item)=('237') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Set ID - OBR' zijn. (string(@LongName)=('Set ID - OBR') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2"
                 priority="3135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('216') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '216' zijn. (string(@Item)=('216') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Placer Order Number' zijn. (string(@LongName)=('Placer Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.1"
                 priority="3133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.2"
                 priority="3132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.3"
                 priority="3131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.4"
                 priority="3130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3"
                 priority="3128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '217' zijn. (string(@Item)=('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Filler Order Number' zijn. (string(@LongName)=('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.1"
                 priority="3126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.2"
                 priority="3125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.3"
                 priority="3124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.4"
                 priority="3123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4"
                 priority="3121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('238') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '238' zijn. (string(@Item)=('238') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Universal Service Identifier' zijn. (string(@LongName)=('Universal Service Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.1"
                 priority="3119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.2"
                 priority="3118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.3"
                 priority="3117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.4"
                 priority="3115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.5"
                 priority="3114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.6"
                 priority="3113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.5"
                 priority="3111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('239') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '239' zijn. (string(@Item)=('239') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority _ OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Priority _ OBR' zijn. (string(@LongName)=('Priority _ OBR') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.6"
                 priority="3109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('240') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '240' zijn. (string(@Item)=('240') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Requested Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Requested Date/Time' zijn. (string(@LongName)=('Requested Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.1"
                 priority="3107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.2"
                 priority="3106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.7"
                 priority="3104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('241') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '241' zijn. (string(@Item)=('241') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Observation Date/Time' zijn. (string(@LongName)=('Observation Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.1"
                 priority="3102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.2"
                 priority="3101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.8"
                 priority="3099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('242') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '242' zijn. (string(@Item)=('242') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Observation End Date/Time' zijn. (string(@LongName)=('Observation End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.1"
                 priority="3097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.2"
                 priority="3096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9"
                 priority="3094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('243') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '243' zijn. (string(@Item)=('243') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Collection Volume' zijn. (string(@LongName)=('Collection Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.1"
                 priority="3092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2"
                 priority="3091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10"
                 priority="3081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('244') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '244' zijn. (string(@Item)=('244') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collector Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Collector Identifier' zijn. (string(@LongName)=('Collector Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.1"
                 priority="3079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2"
                 priority="3078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.3"
                 priority="3071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.4"
                 priority="3070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.5"
                 priority="3069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.6"
                 priority="3068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.7"
                 priority="3067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.8"
                 priority="3066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9"
                 priority="3065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.10"
                 priority="3059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.11"
                 priority="3057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.12"
                 priority="3056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.13"
                 priority="3054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14"
                 priority="3052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.15"
                 priority="3046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16"
                 priority="3044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17"
                 priority="3034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.18"
                 priority="3022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19"
                 priority="3020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20"
                 priority="3015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.21"
                 priority="3010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22"
                 priority="3009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23"
                 priority="2996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.11"
                 priority="2983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('245') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '245' zijn. (string(@Item)=('245') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70065') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70065' zijn. (string(@Table)=('HL70065') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Action Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Action Code' zijn. (string(@LongName)=('Specimen Action Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12"
                 priority="2981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('246') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '246' zijn. (string(@Item)=('246') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Danger Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Danger Code' zijn. (string(@LongName)=('Danger Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.1"
                 priority="2979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.2"
                 priority="2978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.3"
                 priority="2977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.4"
                 priority="2975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.5"
                 priority="2974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.6"
                 priority="2973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.13"
                 priority="2971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('247') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '247' zijn. (string(@Item)=('247') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relevant Clinical Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Relevant Clinical Information' zijn. (string(@LongName)=('Relevant Clinical Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.14"
                 priority="2970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('248') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '248' zijn. (string(@Item)=('248') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Received Date/Time' zijn. (string(@LongName)=('Specimen Received Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.1"
                 priority="2968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.2"
                 priority="2967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15"
                 priority="2965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x]. (count(hl7v2:SPS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x]. (count(hl7v2:SPS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x]. (count(hl7v2:SPS.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x]. (count(hl7v2:SPS.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x]. (count(hl7v2:SPS.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x]. (count(hl7v2:SPS.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x]. (count(hl7v2:SPS.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('249') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '249' zijn. (string(@Item)=('249') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'SPS' zijn. (string(@Type)=('SPS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Specimen Source' zijn. (string(@LongName)=('Specimen Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1"
                 priority="2963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Source Name or Code' zijn. (string(@LongName)=('Specimen Source Name or Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="2961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="2960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="2959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="2957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="2956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="2955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="2953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="2952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="2951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2"
                 priority="2950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70371' zijn. (string(@Table)=('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Additives' zijn. (string(@LongName)=('Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="2948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="2947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="2946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="2944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="2943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="2942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="2940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="2939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="2938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3"
                 priority="2937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Collection Method' zijn. (string(@LongName)=('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape"
                 priority="2936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="2935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4"
                 priority="2933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70163' zijn. (string(@Table)=('HL70163') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Body Site' zijn. (string(@LongName)=('Body Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="2931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="2930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="2929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="2927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="2926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="2925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="2923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="2922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="2921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5"
                 priority="2920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70495' zijn. (string(@Table)=('HL70495') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Site Modifier' zijn. (string(@LongName)=('Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="2918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="2917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="2916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="2914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="2913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="2912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="2910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="2909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="2908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6"
                 priority="2907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Collection Method Modifier Code' zijn. (string(@LongName)=('Collection Method Modifier Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="2905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="2904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="2903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="2901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="2900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="2899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="2897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="2896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="2895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7"
                 priority="2894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70369' zijn. (string(@Table)=('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Role' zijn. (string(@LongName)=('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="2892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="2891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="2890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="2888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="2887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="2886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="2884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="2883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="2882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16"
                 priority="2881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '226' zijn. (string(@Item)=('226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Ordering Provider' zijn. (string(@LongName)=('Ordering Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.1"
                 priority="2879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2"
                 priority="2878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.3"
                 priority="2871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.4"
                 priority="2870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.5"
                 priority="2869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.6"
                 priority="2868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.7"
                 priority="2867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.8"
                 priority="2866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9"
                 priority="2865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.10"
                 priority="2859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.11"
                 priority="2857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.12"
                 priority="2856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.13"
                 priority="2854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14"
                 priority="2852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.15"
                 priority="2846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16"
                 priority="2844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17"
                 priority="2834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.18"
                 priority="2822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19"
                 priority="2820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20"
                 priority="2815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.21"
                 priority="2810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22"
                 priority="2809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23"
                 priority="2796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17"
                 priority="2783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('250') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '250' zijn. (string(@Item)=('250') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Callback Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Order Callback Phone Number' zijn. (string(@LongName)=('Order Callback Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.1"
                 priority="2781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.2"
                 priority="2780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.3"
                 priority="2778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.4"
                 priority="2776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.5"
                 priority="2775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.6"
                 priority="2774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.7"
                 priority="2773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.8"
                 priority="2772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.9"
                 priority="2771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.10"
                 priority="2770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.11"
                 priority="2769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.12"
                 priority="2768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.18"
                 priority="2767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('251') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '251' zijn. (string(@Item)=('251') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Placer Field 1' zijn. (string(@LongName)=('Placer Field 1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.19"
                 priority="2766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('252') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '252' zijn. (string(@Item)=('252') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Placer Field 2' zijn. (string(@LongName)=('Placer Field 2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.20"
                 priority="2765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('253') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '253' zijn. (string(@Item)=('253') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Filler Field 1' zijn. (string(@LongName)=('Filler Field 1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.21"
                 priority="2764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('254') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '254' zijn. (string(@Item)=('254') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Filler Field 2' zijn. (string(@LongName)=('Filler Field 2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.22"
                 priority="2763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('255') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '255' zijn. (string(@Item)=('255') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Results Rpt/Status Chng - Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Results Rpt/Status Chng - Date/Time' zijn. (string(@LongName)=('Results Rpt/Status Chng - Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.1"
                 priority="2761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.2"
                 priority="2760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23"
                 priority="2758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): element hl7v2:MOC.1 komt te vaak voor [max 1x]. (count(hl7v2:MOC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): element hl7v2:MOC.2 komt te vaak voor [max 1x]. (count(hl7v2:MOC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('256') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '256' zijn. (string(@Item)=('256') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MOC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'MOC' zijn. (string(@Type)=('MOC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge to Practice') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Charge to Practice' zijn. (string(@LongName)=('Charge to Practice') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1"
                 priority="2756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Monetary Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @LongName MOET 'Monetary Amount' zijn. (string(@LongName)=('Monetary Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.1"
                 priority="2754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.2"
                 priority="2753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2"
                 priority="2751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @LongName MOET 'Charge Code' zijn. (string(@LongName)=('Charge Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.1"
                 priority="2749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.2"
                 priority="2748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.3"
                 priority="2747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.4"
                 priority="2745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.5"
                 priority="2744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.6"
                 priority="2743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.24"
                 priority="2741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('257') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '257' zijn. (string(@Item)=('257') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70074') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70074' zijn. (string(@Table)=('HL70074') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnostic Serv Sect ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Diagnostic Serv Sect ID' zijn. (string(@LongName)=('Diagnostic Serv Sect ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.25"
                 priority="2739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='F'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBR.25 MOET ''F'' zijn. (text()='F' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='F'"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de element content van hl7v2:OBR.25 MOET ''F'' zijn. (text()='F' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('258') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '258' zijn. (string(@Item)=('258') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70123') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70123' zijn. (string(@Table)=('HL70123') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Result Status' zijn. (string(@LongName)=('Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26"
                 priority="2737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.1 komt te vaak voor [max 1x]. (count(hl7v2:PRL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.2 komt te vaak voor [max 1x]. (count(hl7v2:PRL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.3 komt te vaak voor [max 1x]. (count(hl7v2:PRL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('259') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '259' zijn. (string(@Item)=('259') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PRL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'PRL' zijn. (string(@Type)=('PRL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Result') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Parent Result' zijn. (string(@LongName)=('Parent Result') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1"
                 priority="2735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Identifier' zijn. (string(@LongName)=('Parent Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.1"
                 priority="2733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.2"
                 priority="2732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.3"
                 priority="2731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.4"
                 priority="2729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.5"
                 priority="2728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.6"
                 priority="2727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.2"
                 priority="2725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Sub-identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Sub-identifier' zijn. (string(@LongName)=('Parent Observation Sub-identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3"
                 priority="2724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Value Descriptor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Value Descriptor' zijn. (string(@LongName)=('Parent Observation Value Descriptor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape"
                 priority="2723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape"
                 priority="2722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27"
                 priority="2720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('221') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '221' zijn. (string(@Item)=('221') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'TQ' zijn. (string(@Type)=('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Quantity/Timing' zijn. (string(@LongName)=('Quantity/Timing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1"
                 priority="2718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="2716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="2715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2"
                 priority="2705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'RI' zijn. (string(@Type)=('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Interval' zijn. (string(@LongName)=('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="2703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Repeat Pattern' zijn. (string(@LongName)=('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="2702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Explicit Time Interval' zijn. (string(@LongName)=('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.3"
                 priority="2701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Duration' zijn. (string(@LongName)=('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4"
                 priority="2700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Start Date/Time' zijn. (string(@LongName)=('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="2698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="2697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5"
                 priority="2695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'End Date/Time' zijn. (string(@LongName)=('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="2693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="2692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.6"
                 priority="2690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Priority' zijn. (string(@LongName)=('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.7"
                 priority="2689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Condition' zijn. (string(@LongName)=('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8"
                 priority="2688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape"
                 priority="2687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="2686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.9"
                 priority="2684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Table MOET 'HL70472' zijn. (string(@Table)=('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Conjunction' zijn. (string(@LongName)=('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10"
                 priority="2682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'OSD' zijn. (string(@Type)=('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Order Sequencing' zijn. (string(@LongName)=('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="2680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70524' zijn. (string(@Table)=('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence/Results Flag' zijn. (string(@LongName)=('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="2678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Entity Identifier' zijn. (string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="2677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Namespace ID' zijn. (string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="2676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Entity Identifier' zijn. (string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="2675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Namespace ID' zijn. (string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="2674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence Condition Value' zijn. (string(@LongName)=('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="2673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Maximum Number of Repeats' zijn. (string(@LongName)=('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="2672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID' zijn. (string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="2671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID Type' zijn. (string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="2669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID' zijn. (string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="2668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID Type' zijn. (string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11"
                 priority="2666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Occurrence Duration' zijn. (string(@LongName)=('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="2664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="2663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="2662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="2660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="2659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="2658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.12"
                 priority="2656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Total Occurrences' zijn. (string(@LongName)=('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28"
                 priority="2655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('260') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '260' zijn. (string(@Item)=('260') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Copies To') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Result Copies To' zijn. (string(@LongName)=('Result Copies To') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.1"
                 priority="2653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2"
                 priority="2652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.3"
                 priority="2645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.4"
                 priority="2644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.5"
                 priority="2643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.6"
                 priority="2642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.7"
                 priority="2641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.8"
                 priority="2640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9"
                 priority="2639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.10"
                 priority="2633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.11"
                 priority="2631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.12"
                 priority="2630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.13"
                 priority="2628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14"
                 priority="2626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.15"
                 priority="2620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16"
                 priority="2618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17"
                 priority="2608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.18"
                 priority="2596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19"
                 priority="2594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20"
                 priority="2589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.21"
                 priority="2584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22"
                 priority="2583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23"
                 priority="2570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29"
                 priority="2557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('261') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '261' zijn. (string(@Item)=('261') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'EIP' zijn. (string(@Type)=('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Parent' zijn. (string(@LongName)=('Parent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1"
                 priority="2555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn. (string(@LongName)=('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="2553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="2552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="2551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="2550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2"
                 priority="2548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn. (string(@LongName)=('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="2546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="2545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="2544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="2543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.30"
                 priority="2541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('262') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '262' zijn. (string(@Item)=('262') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70124') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70124' zijn. (string(@Table)=('HL70124') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transportation Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Transportation Mode' zijn. (string(@LongName)=('Transportation Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31"
                 priority="2539"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.413-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.413 RIVM ISIS-AR Reden aanvraag (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.413-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.413-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.413 RIVM ISIS-AR Reden aanvraag (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.413-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('263') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '263' zijn. (string(@Item)=('263') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Reason for Study') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Reason for Study' zijn. (string(@LongName)=('Reason for Study') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.1"
                 priority="2537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.2"
                 priority="2536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.3"
                 priority="2535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.4"
                 priority="2533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.5"
                 priority="2532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.6"
                 priority="2531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32"
                 priority="2529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('264') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '264' zijn. (string(@Item)=('264') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Principal Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Principal Result Interpreter' zijn. (string(@LongName)=('Principal Result Interpreter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1"
                 priority="2527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2"
                 priority="2513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3"
                 priority="2508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.4"
                 priority="2503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.5"
                 priority="2502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.6"
                 priority="2501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7"
                 priority="2500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.8"
                 priority="2494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.9"
                 priority="2493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.10"
                 priority="2492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.11"
                 priority="2491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33"
                 priority="2490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('265') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '265' zijn. (string(@Item)=('265') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assistant Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Assistant Result Interpreter' zijn. (string(@LongName)=('Assistant Result Interpreter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1"
                 priority="2488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2"
                 priority="2474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3"
                 priority="2469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.4"
                 priority="2464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.5"
                 priority="2463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.6"
                 priority="2462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7"
                 priority="2461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.8"
                 priority="2455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.9"
                 priority="2454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.10"
                 priority="2453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.11"
                 priority="2452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34"
                 priority="2451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('266') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '266' zijn. (string(@Item)=('266') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Technician') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Technician' zijn. (string(@LongName)=('Technician') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1"
                 priority="2449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2"
                 priority="2435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3"
                 priority="2430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.4"
                 priority="2425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.5"
                 priority="2424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.6"
                 priority="2423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7"
                 priority="2422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.8"
                 priority="2416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.9"
                 priority="2415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.10"
                 priority="2414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.11"
                 priority="2413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35"
                 priority="2412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('267') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '267' zijn. (string(@Item)=('267') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transcriptionist') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Transcriptionist' zijn. (string(@LongName)=('Transcriptionist') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1"
                 priority="2410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2"
                 priority="2396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3"
                 priority="2391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.4"
                 priority="2386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.5"
                 priority="2385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.6"
                 priority="2384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7"
                 priority="2383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.8"
                 priority="2377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.9"
                 priority="2376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.10"
                 priority="2375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.11"
                 priority="2374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.36"
                 priority="2373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('268') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '268' zijn. (string(@Item)=('268') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Scheduled Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Scheduled Date/Time' zijn. (string(@LongName)=('Scheduled Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.1"
                 priority="2371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.2"
                 priority="2370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.37"
                 priority="2368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1028') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1028' zijn. (string(@Item)=('1028') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Number of Sample Containers *') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Number of Sample Containers *' zijn. (string(@LongName)=('Number of Sample Containers *') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38"
                 priority="2367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1029') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1029' zijn. (string(@Item)=('1029') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Logistics of Collected Sample') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Transport Logistics of Collected Sample' zijn. (string(@LongName)=('Transport Logistics of Collected Sample') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.1"
                 priority="2365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.2"
                 priority="2364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.3"
                 priority="2363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.4"
                 priority="2361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.5"
                 priority="2360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.6"
                 priority="2359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39"
                 priority="2357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1030') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1030' zijn. (string(@Item)=('1030') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collector''s Comment *') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Collector''s Comment *' zijn. (string(@LongName)=('Collector''s Comment *') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.1"
                 priority="2355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.2"
                 priority="2354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.3"
                 priority="2353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.4"
                 priority="2351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.5"
                 priority="2350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.6"
                 priority="2349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40"
                 priority="2347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1031') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1031' zijn. (string(@Item)=('1031') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Arrangement Responsibility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Transport Arrangement Responsibility' zijn. (string(@LongName)=('Transport Arrangement Responsibility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.1"
                 priority="2345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.2"
                 priority="2344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.3"
                 priority="2343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.4"
                 priority="2341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.5"
                 priority="2340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.6"
                 priority="2339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.41"
                 priority="2337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1032') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1032' zijn. (string(@Item)=('1032') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70224') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70224' zijn. (string(@Table)=('HL70224') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Arranged') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Transport Arranged' zijn. (string(@LongName)=('Transport Arranged') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.42"
                 priority="2335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1033') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1033' zijn. (string(@Item)=('1033') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70225') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70225' zijn. (string(@Table)=('HL70225') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Escort Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Escort Required' zijn. (string(@LongName)=('Escort Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43"
                 priority="2333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1034') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1034' zijn. (string(@Item)=('1034') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Planned Patient Transport Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Planned Patient Transport Comment' zijn. (string(@LongName)=('Planned Patient Transport Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.1"
                 priority="2331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.2"
                 priority="2330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.3"
                 priority="2329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.4"
                 priority="2327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.5"
                 priority="2326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.6"
                 priority="2325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44"
                 priority="2323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('393') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '393' zijn. (string(@Item)=('393') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70088') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70088' zijn. (string(@Table)=('HL70088') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Procedure Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Procedure Code' zijn. (string(@LongName)=('Procedure Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.1"
                 priority="2321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.2"
                 priority="2320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.3"
                 priority="2319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.4"
                 priority="2317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.5"
                 priority="2316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.6"
                 priority="2315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45"
                 priority="2313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1316') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1316' zijn. (string(@Item)=('1316') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70340') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70340' zijn. (string(@Table)=('HL70340') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Procedure Code Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Procedure Code Modifier' zijn. (string(@LongName)=('Procedure Code Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.1"
                 priority="2311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.2"
                 priority="2310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.3"
                 priority="2309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.4"
                 priority="2307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.5"
                 priority="2306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.6"
                 priority="2305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46"
                 priority="2303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1474') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1474' zijn. (string(@Item)=('1474') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70411' zijn. (string(@Table)=('HL70411') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Placer Supplemental Service Information' zijn. (string(@LongName)=('Placer Supplemental Service Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.1"
                 priority="2301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.2"
                 priority="2300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.3"
                 priority="2299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.4"
                 priority="2297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.5"
                 priority="2296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.6"
                 priority="2295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47"
                 priority="2293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1475') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1475' zijn. (string(@Item)=('1475') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70411' zijn. (string(@Table)=('HL70411') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Filler Supplemental Service Information' zijn. (string(@LongName)=('Filler Supplemental Service Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.1"
                 priority="2291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.2"
                 priority="2290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.3"
                 priority="2289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.4"
                 priority="2287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.5"
                 priority="2286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.6"
                 priority="2285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48"
                 priority="2283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1646') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1646' zijn. (string(@Item)=('1646') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70476') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70476' zijn. (string(@Table)=('HL70476') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Medically Necessary Duplicate Procedure Reason.' zijn. (string(@LongName)=('Medically Necessary Duplicate Procedure Reason.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.1"
                 priority="2281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.2"
                 priority="2280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.3"
                 priority="2279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.4"
                 priority="2277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.5"
                 priority="2276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.6"
                 priority="2275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.7"
                 priority="2273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.8"
                 priority="2272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.9"
                 priority="2271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OBR/hl7v2:OBR.49"
                 priority="2270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1647') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Item MOET '1647' zijn. (string(@Item)=('1647') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70507') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70507' zijn. (string(@Table)=('HL70507') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Handling') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Result Handling' zijn. (string(@LongName)=('Result Handling') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.44-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC"
                 priority="2269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.1 is required [min 1x]. (count(hl7v2:ORC.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.1 komt te vaak voor [max 1x]. (count(hl7v2:ORC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.2 is required [min 1x]. (count(hl7v2:ORC.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.2 komt te vaak voor [max 1x]. (count(hl7v2:ORC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.3 is required [min 1x]. (count(hl7v2:ORC.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.3 komt te vaak voor [max 1x]. (count(hl7v2:ORC.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.4 komt te vaak voor [max 1x]. (count(hl7v2:ORC.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.5 komt te vaak voor [max 1x]. (count(hl7v2:ORC.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.6 komt te vaak voor [max 1x]. (count(hl7v2:ORC.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.8 komt te vaak voor [max 1x]. (count(hl7v2:ORC.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.9 komt te vaak voor [max 1x]. (count(hl7v2:ORC.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.13 komt te vaak voor [max 1x]. (count(hl7v2:ORC.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.15 komt te vaak voor [max 1x]. (count(hl7v2:ORC.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.16 komt te vaak voor [max 1x]. (count(hl7v2:ORC.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.17 komt te vaak voor [max 1x]. (count(hl7v2:ORC.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.18 komt te vaak voor [max 1x]. (count(hl7v2:ORC.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.20 komt te vaak voor [max 1x]. (count(hl7v2:ORC.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.25 komt te vaak voor [max 1x]. (count(hl7v2:ORC.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.26 komt te vaak voor [max 1x]. (count(hl7v2:ORC.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.27 komt te vaak voor [max 1x]. (count(hl7v2:ORC.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.28 komt te vaak voor [max 1x]. (count(hl7v2:ORC.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.29 komt te vaak voor [max 1x]. (count(hl7v2:ORC.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): element hl7v2:ORC.30 komt te vaak voor [max 1x]. (count(hl7v2:ORC.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.1"
                 priority="2268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('215') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '215' zijn. (string(@Item)=('215') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70119') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70119' zijn. (string(@Table)=('HL70119') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Control') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Control' zijn. (string(@LongName)=('Order Control') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2"
                 priority="2266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('216') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '216' zijn. (string(@Item)=('216') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Placer Order Number' zijn. (string(@LongName)=('Placer Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.1"
                 priority="2264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.2"
                 priority="2263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.3"
                 priority="2262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.4"
                 priority="2261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3"
                 priority="2259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '217' zijn. (string(@Item)=('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Filler Order Number' zijn. (string(@LongName)=('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.1"
                 priority="2257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.2"
                 priority="2256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.3"
                 priority="2255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.4"
                 priority="2254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4"
                 priority="2252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('218') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '218' zijn. (string(@Item)=('218') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Placer Group Number' zijn. (string(@LongName)=('Placer Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.1"
                 priority="2250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.2"
                 priority="2249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.3"
                 priority="2248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.4"
                 priority="2247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.5"
                 priority="2245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('219') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '219' zijn. (string(@Item)=('219') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70038') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70038' zijn. (string(@Table)=('HL70038') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Status' zijn. (string(@LongName)=('Order Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.6"
                 priority="2243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('220') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '220' zijn. (string(@Item)=('220') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70121') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70121' zijn. (string(@Table)=('HL70121') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Response Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Response Flag' zijn. (string(@LongName)=('Response Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7"
                 priority="2241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('221') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '221' zijn. (string(@Item)=('221') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TQ' zijn. (string(@Type)=('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Quantity/Timing' zijn. (string(@LongName)=('Quantity/Timing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1"
                 priority="2239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="2237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="2236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2"
                 priority="2226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'RI' zijn. (string(@Type)=('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Interval' zijn. (string(@LongName)=('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="2224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Repeat Pattern' zijn. (string(@LongName)=('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="2223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Explicit Time Interval' zijn. (string(@LongName)=('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.3"
                 priority="2222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Duration' zijn. (string(@LongName)=('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4"
                 priority="2221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Start Date/Time' zijn. (string(@LongName)=('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="2219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="2218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5"
                 priority="2216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'End Date/Time' zijn. (string(@LongName)=('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="2214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="2213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.6"
                 priority="2211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Priority' zijn. (string(@LongName)=('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.7"
                 priority="2210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Condition' zijn. (string(@LongName)=('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8"
                 priority="2209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape"
                 priority="2208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="2207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.9"
                 priority="2205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Table MOET 'HL70472' zijn. (string(@Table)=('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Conjunction' zijn. (string(@LongName)=('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10"
                 priority="2203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'OSD' zijn. (string(@Type)=('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Order Sequencing' zijn. (string(@LongName)=('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="2201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70524' zijn. (string(@Table)=('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence/Results Flag' zijn. (string(@LongName)=('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="2199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Entity Identifier' zijn. (string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="2198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Namespace ID' zijn. (string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="2197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Entity Identifier' zijn. (string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="2196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Namespace ID' zijn. (string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="2195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence Condition Value' zijn. (string(@LongName)=('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="2194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Maximum Number of Repeats' zijn. (string(@LongName)=('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="2193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID' zijn. (string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="2192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID Type' zijn. (string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="2190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID' zijn. (string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="2189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID Type' zijn. (string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11"
                 priority="2187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Occurrence Duration' zijn. (string(@LongName)=('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="2185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="2184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="2183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="2181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="2180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="2179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.12"
                 priority="2177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Total Occurrences' zijn. (string(@LongName)=('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8"
                 priority="2176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('222') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '222' zijn. (string(@Item)=('222') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EIP' zijn. (string(@Type)=('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Parent' zijn. (string(@LongName)=('Parent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1"
                 priority="2174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn. (string(@LongName)=('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="2172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="2171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="2170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="2169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2"
                 priority="2167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn. (string(@LongName)=('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="2165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="2164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="2163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="2162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.9"
                 priority="2160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('223') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '223' zijn. (string(@Item)=('223') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of Transaction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Date/Time of Transaction' zijn. (string(@LongName)=('Date/Time of Transaction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.1"
                 priority="2158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.2"
                 priority="2157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10"
                 priority="2155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('224') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '224' zijn. (string(@Item)=('224') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entered By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Entered By' zijn. (string(@LongName)=('Entered By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.1"
                 priority="2153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2"
                 priority="2152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.3"
                 priority="2145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.4"
                 priority="2144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.5"
                 priority="2143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.6"
                 priority="2142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.7"
                 priority="2141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.8"
                 priority="2140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9"
                 priority="2139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.10"
                 priority="2133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.11"
                 priority="2131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.12"
                 priority="2130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.13"
                 priority="2128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14"
                 priority="2126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.15"
                 priority="2120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16"
                 priority="2118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17"
                 priority="2108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.18"
                 priority="2096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19"
                 priority="2094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20"
                 priority="2089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.21"
                 priority="2084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22"
                 priority="2083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23"
                 priority="2070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11"
                 priority="2057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('225') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '225' zijn. (string(@Item)=('225') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Verified By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Verified By' zijn. (string(@LongName)=('Verified By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.1"
                 priority="2055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2"
                 priority="2054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.3"
                 priority="2047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.4"
                 priority="2046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.5"
                 priority="2045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.6"
                 priority="2044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.7"
                 priority="2043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.8"
                 priority="2042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9"
                 priority="2041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.10"
                 priority="2035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.11"
                 priority="2033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.12"
                 priority="2032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.13"
                 priority="2030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14"
                 priority="2028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.15"
                 priority="2022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16"
                 priority="2020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17"
                 priority="2010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.18"
                 priority="1998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19"
                 priority="1996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20"
                 priority="1991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.21"
                 priority="1986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22"
                 priority="1985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23"
                 priority="1972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12"
                 priority="1959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '226' zijn. (string(@Item)=('226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Provider' zijn. (string(@LongName)=('Ordering Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.1"
                 priority="1957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2"
                 priority="1956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.3"
                 priority="1949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.4"
                 priority="1948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.5"
                 priority="1947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.6"
                 priority="1946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.7"
                 priority="1945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.8"
                 priority="1944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9"
                 priority="1943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.10"
                 priority="1937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.11"
                 priority="1935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.12"
                 priority="1934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.13"
                 priority="1932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14"
                 priority="1930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.15"
                 priority="1924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16"
                 priority="1922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17"
                 priority="1912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.18"
                 priority="1900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19"
                 priority="1898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20"
                 priority="1893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.21"
                 priority="1888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22"
                 priority="1887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23"
                 priority="1874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13"
                 priority="1861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('227') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '227' zijn. (string(@Item)=('227') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Enterer''s Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Enterer''s Location' zijn. (string(@LongName)=('Enterer''s Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.1"
                 priority="1859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.2"
                 priority="1858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.3"
                 priority="1857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4"
                 priority="1856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.1"
                 priority="1854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.2"
                 priority="1853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.3"
                 priority="1852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.5"
                 priority="1850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.6"
                 priority="1849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.7"
                 priority="1848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.8"
                 priority="1847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.9"
                 priority="1846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10"
                 priority="1845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.1"
                 priority="1843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.2"
                 priority="1842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.3"
                 priority="1841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.4"
                 priority="1840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11"
                 priority="1838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.1"
                 priority="1836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.2"
                 priority="1835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.3"
                 priority="1834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14"
                 priority="1832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('228') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '228' zijn. (string(@Item)=('228') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Call Back Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Call Back Phone Number' zijn. (string(@LongName)=('Call Back Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.1"
                 priority="1830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.2"
                 priority="1829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.3"
                 priority="1827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.4"
                 priority="1825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.5"
                 priority="1824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.6"
                 priority="1823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.7"
                 priority="1822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.8"
                 priority="1821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.9"
                 priority="1820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.10"
                 priority="1819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.11"
                 priority="1818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.12"
                 priority="1817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.15"
                 priority="1816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('229') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '229' zijn. (string(@Item)=('229') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Effective Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Effective Date/Time' zijn. (string(@LongName)=('Order Effective Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.1"
                 priority="1814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.2"
                 priority="1813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16"
                 priority="1811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('230') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '230' zijn. (string(@Item)=('230') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Control Code Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Control Code Reason' zijn. (string(@LongName)=('Order Control Code Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.1"
                 priority="1809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.2"
                 priority="1808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.3"
                 priority="1807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.4"
                 priority="1805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.5"
                 priority="1804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.6"
                 priority="1803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17"
                 priority="1801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('231') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '231' zijn. (string(@Item)=('231') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entering Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Entering Organization' zijn. (string(@LongName)=('Entering Organization') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.1"
                 priority="1799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.2"
                 priority="1798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.3"
                 priority="1797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.4"
                 priority="1795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.5"
                 priority="1794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.6"
                 priority="1793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18"
                 priority="1791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('232') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '232' zijn. (string(@Item)=('232') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entering Device') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Entering Device' zijn. (string(@LongName)=('Entering Device') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.1"
                 priority="1789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.2"
                 priority="1788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.3"
                 priority="1787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.4"
                 priority="1785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.5"
                 priority="1784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.6"
                 priority="1783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19"
                 priority="1781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('233') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '233' zijn. (string(@Item)=('233') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Action By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Action By' zijn. (string(@LongName)=('Action By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.1"
                 priority="1779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2"
                 priority="1778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.3"
                 priority="1771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.4"
                 priority="1770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.5"
                 priority="1769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.6"
                 priority="1768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.7"
                 priority="1767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.8"
                 priority="1766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9"
                 priority="1765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.10"
                 priority="1759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.11"
                 priority="1757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.12"
                 priority="1756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.13"
                 priority="1754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14"
                 priority="1752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.15"
                 priority="1746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16"
                 priority="1744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17"
                 priority="1734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.18"
                 priority="1722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19"
                 priority="1720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20"
                 priority="1715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.21"
                 priority="1710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22"
                 priority="1709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23"
                 priority="1696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20"
                 priority="1683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1310') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1310' zijn. (string(@Item)=('1310') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70339') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70339' zijn. (string(@Table)=('HL70339') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advanced Beneficiary Notice Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Advanced Beneficiary Notice Code' zijn. (string(@LongName)=('Advanced Beneficiary Notice Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.1"
                 priority="1681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.2"
                 priority="1680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.3"
                 priority="1679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.4"
                 priority="1677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.5"
                 priority="1676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.6"
                 priority="1675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21"
                 priority="1673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1311') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1311' zijn. (string(@Item)=('1311') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Facility Name' zijn. (string(@LongName)=('Ordering Facility Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.1"
                 priority="1671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.2"
                 priority="1670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.3"
                 priority="1669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.4"
                 priority="1668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.5"
                 priority="1667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6"
                 priority="1665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.1"
                 priority="1663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.2"
                 priority="1662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.3"
                 priority="1661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.7"
                 priority="1659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8"
                 priority="1657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.1"
                 priority="1655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.2"
                 priority="1654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.3"
                 priority="1653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.9"
                 priority="1651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.10"
                 priority="1649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22"
                 priority="1648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1312') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1312' zijn. (string(@Item)=('1312') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Facility Address' zijn. (string(@LongName)=('Ordering Facility Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1"
                 priority="1646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="1644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="1643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="1642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.2"
                 priority="1641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.3"
                 priority="1640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.4"
                 priority="1639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.5"
                 priority="1638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.6"
                 priority="1637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.7"
                 priority="1635"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.8"
                 priority="1633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.9"
                 priority="1632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.10"
                 priority="1631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.11"
                 priority="1630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12"
                 priority="1628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="1626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="1621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13"
                 priority="1616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="1614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="1613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14"
                 priority="1611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="1609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="1608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23"
                 priority="1606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1313') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1313' zijn. (string(@Item)=('1313') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Facility Phone Number' zijn. (string(@LongName)=('Ordering Facility Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.1"
                 priority="1604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.2"
                 priority="1603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.3"
                 priority="1601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.4"
                 priority="1599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.5"
                 priority="1598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.6"
                 priority="1597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.7"
                 priority="1596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.8"
                 priority="1595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.9"
                 priority="1594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.10"
                 priority="1593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.11"
                 priority="1592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.12"
                 priority="1591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24"
                 priority="1590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1314') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1314' zijn. (string(@Item)=('1314') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Ordering Provider Address' zijn. (string(@LongName)=('Ordering Provider Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1"
                 priority="1588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="1586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="1585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="1584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.2"
                 priority="1583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.3"
                 priority="1582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.4"
                 priority="1581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.5"
                 priority="1580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.6"
                 priority="1579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.7"
                 priority="1577"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.8"
                 priority="1575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.9"
                 priority="1574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.10"
                 priority="1573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.11"
                 priority="1572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12"
                 priority="1570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="1568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="1563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13"
                 priority="1558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="1556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="1555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14"
                 priority="1553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="1551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="1550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25"
                 priority="1548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1473') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1473' zijn. (string(@Item)=('1473') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Status Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Status Modifier' zijn. (string(@LongName)=('Order Status Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.1"
                 priority="1546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.2"
                 priority="1545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.3"
                 priority="1544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.4"
                 priority="1542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.5"
                 priority="1541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.6"
                 priority="1540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.7"
                 priority="1538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.8"
                 priority="1537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.9"
                 priority="1536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26"
                 priority="1535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1641') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1641' zijn. (string(@Item)=('1641') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70552') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70552' zijn. (string(@Table)=('HL70552') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advanced Beneficiary Notice Override Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Advanced Beneficiary Notice Override Reason' zijn. (string(@LongName)=('Advanced Beneficiary Notice Override Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.1"
                 priority="1533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.2"
                 priority="1532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.3"
                 priority="1531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.4"
                 priority="1529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.5"
                 priority="1528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.6"
                 priority="1527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.7"
                 priority="1525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.8"
                 priority="1524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.9"
                 priority="1523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.27"
                 priority="1522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1642') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1642' zijn. (string(@Item)=('1642') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler''s Expected Availability Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Filler''s Expected Availability Date/Time' zijn. (string(@LongName)=('Filler''s Expected Availability Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.1"
                 priority="1520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.2"
                 priority="1519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28"
                 priority="1517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('615') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '615' zijn. (string(@Item)=('615') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70177') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70177' zijn. (string(@Table)=('HL70177') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Confidentiality Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Confidentiality Code' zijn. (string(@LongName)=('Confidentiality Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.1"
                 priority="1515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.2"
                 priority="1514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.3"
                 priority="1513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.4"
                 priority="1511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.5"
                 priority="1510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.6"
                 priority="1509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.7"
                 priority="1507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.8"
                 priority="1506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.9"
                 priority="1505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29"
                 priority="1504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1643') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1643' zijn. (string(@Item)=('1643') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70482') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70482' zijn. (string(@Table)=('HL70482') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Order Type' zijn. (string(@LongName)=('Order Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.1"
                 priority="1502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.2"
                 priority="1501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.3"
                 priority="1500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.4"
                 priority="1498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.5"
                 priority="1497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.6"
                 priority="1496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.7"
                 priority="1494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.8"
                 priority="1493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.9"
                 priority="1492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30"
                 priority="1491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x]. (count(hl7v2:CNE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x]. (count(hl7v2:CNE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x]. (count(hl7v2:CNE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x]. (count(hl7v2:CNE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x]. (count(hl7v2:CNE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x]. (count(hl7v2:CNE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x]. (count(hl7v2:CNE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x]. (count(hl7v2:CNE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x]. (count(hl7v2:CNE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1644') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1644' zijn. (string(@Item)=('1644') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CNE' zijn. (string(@Type)=('CNE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70483') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70483' zijn. (string(@Table)=('HL70483') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Enterer Authorization Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Enterer Authorization Mode' zijn. (string(@LongName)=('Enterer Authorization Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.33-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.1"
                 priority="1489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.2"
                 priority="1488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.3"
                 priority="1487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.4"
                 priority="1485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.5"
                 priority="1484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.6"
                 priority="1483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.7"
                 priority="1481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.8"
                 priority="1480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.9"
                 priority="1479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE"
                 priority="1478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.1"
                 priority="1477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.2"
                 priority="1476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3"
                 priority="1474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="1473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="1472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4"
                 priority="1470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="1468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="1467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="1466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="1464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="1463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="1462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e9886-false-d914139e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY"
                 priority="1460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:TQ1 is required [min 1x]. (count(hl7v2:TQ1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:TQ1 komt te vaak voor [max 1x]. (count(hl7v2:TQ1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1"
                 priority="1459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.13 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.14 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.1"
                 priority="1458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1627') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1627' zijn. (string(@Item)=('1627') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - TQ1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Set ID - TQ1' zijn. (string(@LongName)=('Set ID - TQ1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2"
                 priority="1457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1628') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1628' zijn. (string(@Item)=('1628') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.1"
                 priority="1455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2"
                 priority="1454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3"
                 priority="1444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.1 komt te vaak voor [max 1x]. (count(hl7v2:RPT.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.2 komt te vaak voor [max 1x]. (count(hl7v2:RPT.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.3 komt te vaak voor [max 1x]. (count(hl7v2:RPT.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.4 komt te vaak voor [max 1x]. (count(hl7v2:RPT.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.5 komt te vaak voor [max 1x]. (count(hl7v2:RPT.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.6 komt te vaak voor [max 1x]. (count(hl7v2:RPT.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.7 komt te vaak voor [max 1x]. (count(hl7v2:RPT.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.8 komt te vaak voor [max 1x]. (count(hl7v2:RPT.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.9 komt te vaak voor [max 1x]. (count(hl7v2:RPT.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.10 komt te vaak voor [max 1x]. (count(hl7v2:RPT.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.11 komt te vaak voor [max 1x]. (count(hl7v2:RPT.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1629') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1629' zijn. (string(@Item)=('1629') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RPT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'RPT' zijn. (string(@Type)=('RPT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Repeat Pattern' zijn. (string(@LongName)=('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1"
                 priority="1442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Repeat Pattern Code' zijn. (string(@LongName)=('Repeat Pattern Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.1"
                 priority="1440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.2"
                 priority="1439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.3"
                 priority="1438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.4"
                 priority="1436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.5"
                 priority="1435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.6"
                 priority="1434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.7"
                 priority="1432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.8"
                 priority="1431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.9"
                 priority="1430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.2"
                 priority="1429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70527') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70527' zijn. (string(@Table)=('HL70527') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Calendar Alignment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Calendar Alignment' zijn. (string(@LongName)=('Calendar Alignment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.3"
                 priority="1427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phase Range Begin Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Phase Range Begin Value' zijn. (string(@LongName)=('Phase Range Begin Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.4"
                 priority="1426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phase Range End Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Phase Range End Value' zijn. (string(@LongName)=('Phase Range End Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.5"
                 priority="1425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Period Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Period Quantity' zijn. (string(@LongName)=('Period Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.6"
                 priority="1424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Period Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Period Units' zijn. (string(@LongName)=('Period Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.7"
                 priority="1423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Institution Specified Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Institution Specified Time' zijn. (string(@LongName)=('Institution Specified Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.8"
                 priority="1421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70528') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70528' zijn. (string(@Table)=('HL70528') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Event' zijn. (string(@LongName)=('Event') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.9"
                 priority="1419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event Offset Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Event Offset Quantity' zijn. (string(@LongName)=('Event Offset Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.10"
                 priority="1418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event Offset Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Event Offset Units' zijn. (string(@LongName)=('Event Offset Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.11"
                 priority="1417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('GTS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'GTS' zijn. (string(@Type)=('GTS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('General Timing Specification') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'General Timing Specification' zijn. (string(@LongName)=('General Timing Specification') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.4"
                 priority="1416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1630') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1630' zijn. (string(@Item)=('1630') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TM' zijn. (string(@Type)=('TM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Explicit Time' zijn. (string(@LongName)=('Explicit Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5"
                 priority="1415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1631') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1631' zijn. (string(@Item)=('1631') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relative Time and Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Relative Time and Units' zijn. (string(@LongName)=('Relative Time and Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.1"
                 priority="1413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2"
                 priority="1412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6"
                 priority="1402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1632') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1632' zijn. (string(@Item)=('1632') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Service Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Service Duration' zijn. (string(@LongName)=('Service Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.1"
                 priority="1400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2"
                 priority="1399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.7"
                 priority="1389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1633') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1633' zijn. (string(@Item)=('1633') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Start date/time' zijn. (string(@LongName)=('Start date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.1"
                 priority="1387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.2"
                 priority="1386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.8"
                 priority="1384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1634') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1634' zijn. (string(@Item)=('1634') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'End date/time' zijn. (string(@LongName)=('End date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.1"
                 priority="1382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.2"
                 priority="1381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9"
                 priority="1379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1635') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1635' zijn. (string(@Item)=('1635') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70485') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70485' zijn. (string(@Table)=('HL70485') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Priority' zijn. (string(@LongName)=('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.1"
                 priority="1377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.2"
                 priority="1376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.3"
                 priority="1375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.4"
                 priority="1373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.5"
                 priority="1372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.6"
                 priority="1371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.7"
                 priority="1369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.8"
                 priority="1368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.9"
                 priority="1367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10"
                 priority="1366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1636') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1636' zijn. (string(@Item)=('1636') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Condition text' zijn. (string(@LongName)=('Condition text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape"
                 priority="1365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape"
                 priority="1364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11"
                 priority="1362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1637') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1637' zijn. (string(@Item)=('1637') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text instruction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Text instruction' zijn. (string(@LongName)=('Text instruction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape"
                 priority="1361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape"
                 priority="1360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.12"
                 priority="1358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1638') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1638' zijn. (string(@Item)=('1638') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70427') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70427' zijn. (string(@Table)=('HL70427') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Conjunction' zijn. (string(@LongName)=('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13"
                 priority="1356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1639') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1639' zijn. (string(@Item)=('1639') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Occurrence duration' zijn. (string(@LongName)=('Occurrence duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.1"
                 priority="1354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2"
                 priority="1353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ1/hl7v2:TQ1.14"
                 priority="1343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1640') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1640' zijn. (string(@Item)=('1640') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total occurrence''s') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Total occurrence''s' zijn. (string(@LongName)=('Total occurrence''s') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2"
                 priority="1342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.1"
                 priority="1341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1648') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1648' zijn. (string(@Item)=('1648') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - TQ2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Set ID - TQ2' zijn. (string(@LongName)=('Set ID - TQ2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.2"
                 priority="1340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1649') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1649' zijn. (string(@Item)=('1649') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70503') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70503' zijn. (string(@Table)=('HL70503') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Sequence/Results Flag' zijn. (string(@LongName)=('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3"
                 priority="1338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1650') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1650' zijn. (string(@Item)=('1650') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Placer Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Related Placer Number' zijn. (string(@LongName)=('Related Placer Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.1"
                 priority="1336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.2"
                 priority="1335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.3"
                 priority="1334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.4"
                 priority="1333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4"
                 priority="1331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1651') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1651' zijn. (string(@Item)=('1651') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Filler Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Related Filler Number' zijn. (string(@LongName)=('Related Filler Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.1"
                 priority="1329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.2"
                 priority="1328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.3"
                 priority="1327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.4"
                 priority="1326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5"
                 priority="1324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1652') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1652' zijn. (string(@Item)=('1652') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Related Placer Group Number' zijn. (string(@LongName)=('Related Placer Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.1"
                 priority="1322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.2"
                 priority="1321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.3"
                 priority="1320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.4"
                 priority="1319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.6"
                 priority="1317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1653') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1653' zijn. (string(@Item)=('1653') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70504') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70504' zijn. (string(@Table)=('HL70504') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Sequence Condition Code' zijn. (string(@LongName)=('Sequence Condition Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.7"
                 priority="1315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1654') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1654' zijn. (string(@Item)=('1654') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70505') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70505' zijn. (string(@Table)=('HL70505') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cyclic Entry/Exit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Cyclic Entry/Exit Indicator' zijn. (string(@LongName)=('Cyclic Entry/Exit Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8"
                 priority="1313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1655') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1655' zijn. (string(@Item)=('1655') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Sequence Condition Time Interval' zijn. (string(@LongName)=('Sequence Condition Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.1"
                 priority="1311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2"
                 priority="1310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.9"
                 priority="1300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1656') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1656' zijn. (string(@Item)=('1656') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cyclic Group Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Cyclic Group Maximum Number of Repeats' zijn. (string(@LongName)=('Cyclic Group Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.TIMING_QTY/hl7v2:TQ2/hl7v2:TQ2.10"
                 priority="1299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1657') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1657' zijn. (string(@Item)=('1657') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70506') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70506' zijn. (string(@Table)=('HL70506') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Service Request Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Special Service Request Relationship' zijn. (string(@LongName)=('Special Service Request Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e9896-false-d918075e0-->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT"
                 priority="1297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OUL_R22_Lab2PublicHealth): element hl7v2:TCD komt te vaak voor [max 1x]. (count(hl7v2:TCD)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX"
                 priority="1296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.8 komt te vaak voor [max 1x]. (count(hl7v2:OBX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.1"
                 priority="1295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.2"
                 priority="1294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE' or text()='NM' or text()='SN' or text()='TM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''CNE' of 'NM' of 'SN' of 'TM'' zijn. (text()='CNE' or text()='NM' or text()='SN' or text()='TM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE' or text()='NM' or text()='SN' or text()='TM'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de element content van hl7v2:OBX.2 MOET ''CNE' of 'NM' of 'SN' of 'TM'' zijn. (text()='CNE' or text()='NM' or text()='SN' or text()='TM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3"
                 priority="1292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="1290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="1289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="1288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="1286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="1285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="1284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.4"
                 priority="1282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.5"
                 priority="1281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6"
                 priority="1280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="1278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="1277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="1276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="1274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="1273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="1272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.7"
                 priority="1270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.8"
                 priority="1269"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.9"
                 priority="1267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.10"
                 priority="1266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.11"
                 priority="1264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='F'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.11 MOET ''F'' zijn. (text()='F' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='F'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de element content van hl7v2:OBX.11 MOET ''F'' zijn. (text()='F' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12"
                 priority="1262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="1260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="1259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.13"
                 priority="1257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14"
                 priority="1256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="1254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="1253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15"
                 priority="1251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="1249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="1248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="1247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="1245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="1244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="1243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16"
                 priority="1241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="1239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="1238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="1231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="1230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="1229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="1228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="1227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="1226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="1225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="1219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="1217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="1216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="1214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="1212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="1206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="1204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="1194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="1182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="1180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="1175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="1170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="1169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="1156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17"
                 priority="1143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="1141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="1140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="1139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="1137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="1136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="1135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18"
                 priority="1133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="1131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="1130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="1129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="1128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19"
                 priority="1126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2PublicHealth): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.46-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="1124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="1123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD"
                 priority="1121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.1 is required [min 1x]. (count(hl7v2:TCD.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.1 komt te vaak voor [max 1x]. (count(hl7v2:TCD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.2 komt te vaak voor [max 1x]. (count(hl7v2:TCD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.3 komt te vaak voor [max 1x]. (count(hl7v2:TCD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.4 komt te vaak voor [max 1x]. (count(hl7v2:TCD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.5 komt te vaak voor [max 1x]. (count(hl7v2:TCD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.6 komt te vaak voor [max 1x]. (count(hl7v2:TCD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.7 komt te vaak voor [max 1x]. (count(hl7v2:TCD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.8 komt te vaak voor [max 1x]. (count(hl7v2:TCD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1"
                 priority="1120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('238') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '238' zijn. (string(@Item)=('238') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Universal Service Identifier' zijn. (string(@LongName)=('Universal Service Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.1"
                 priority="1118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.2"
                 priority="1117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.3"
                 priority="1116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.4"
                 priority="1114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.5"
                 priority="1113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.6"
                 priority="1112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2"
                 priority="1110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1420') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1420' zijn. (string(@Item)=('1420') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Auto-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Auto-Dilution Factor' zijn. (string(@LongName)=('Auto-Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.1"
                 priority="1108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.2"
                 priority="1107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.3"
                 priority="1106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.4"
                 priority="1105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3"
                 priority="1104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1421') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1421' zijn. (string(@Item)=('1421') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Rerun Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Rerun Dilution Factor' zijn. (string(@LongName)=('Rerun Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.1"
                 priority="1102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.2"
                 priority="1101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.3"
                 priority="1100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.4"
                 priority="1099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4"
                 priority="1098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1422') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1422' zijn. (string(@Item)=('1422') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Pre-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Pre-Dilution Factor' zijn. (string(@LongName)=('Pre-Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.1"
                 priority="1096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.2"
                 priority="1095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.3"
                 priority="1094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.4"
                 priority="1093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5"
                 priority="1092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1413') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1413' zijn. (string(@Item)=('1413') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Endogenous Content of Pre-Dilution Diluent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Endogenous Content of Pre-Dilution Diluent' zijn. (string(@LongName)=('Endogenous Content of Pre-Dilution Diluent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.1"
                 priority="1090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.2"
                 priority="1089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.3"
                 priority="1088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.4"
                 priority="1087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.6"
                 priority="1086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1416') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1416' zijn. (string(@Item)=('1416') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Automatic Repeat Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Automatic Repeat Allowed' zijn. (string(@LongName)=('Automatic Repeat Allowed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.7"
                 priority="1084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1424') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1424' zijn. (string(@Item)=('1424') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Reflex Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Reflex Allowed' zijn. (string(@LongName)=('Reflex Allowed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8"
                 priority="1082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1425') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1425' zijn. (string(@Item)=('1425') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70389') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Table MOET 'HL70389' zijn. (string(@Table)=('HL70389') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Analyte Repeat Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Analyte Repeat Status' zijn. (string(@LongName)=('Analyte Repeat Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.1"
                 priority="1080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.2"
                 priority="1079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.3"
                 priority="1078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.4"
                 priority="1076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.5"
                 priority="1075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.6"
                 priority="1074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID"
                 priority="1072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): element hl7v2:SID.1 komt te vaak voor [max 1x]. (count(hl7v2:SID.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): element hl7v2:SID.2 komt te vaak voor [max 1x]. (count(hl7v2:SID.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): element hl7v2:SID.3 komt te vaak voor [max 1x]. (count(hl7v2:SID.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SID.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): element hl7v2:SID.4 komt te vaak voor [max 1x]. (count(hl7v2:SID.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1"
                 priority="1071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1426') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @Item MOET '1426' zijn. (string(@Item)=('1426') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Application / Method Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @LongName MOET 'Application / Method Identifier' zijn. (string(@LongName)=('Application / Method Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.1"
                 priority="1069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.2"
                 priority="1068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.3"
                 priority="1067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.4"
                 priority="1065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.5"
                 priority="1064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.1/hl7v2:CE.6"
                 priority="1063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.2"
                 priority="1061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @Item MOET '1129' zijn. (string(@Item)=('1129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Lot Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @LongName MOET 'Substance Lot Number' zijn. (string(@LongName)=('Substance Lot Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.3"
                 priority="1060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1428') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @Item MOET '1428' zijn. (string(@Item)=('1428') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @LongName MOET 'Substance Container Identifier' zijn. (string(@LongName)=('Substance Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4"
                 priority="1059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1429') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @Item MOET '1429' zijn. (string(@Item)=('1429') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70385') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @Table MOET 'HL70385' zijn. (string(@Table)=('HL70385') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Substance Manufacturer Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SID_segment): de waarde van @LongName MOET 'Substance Manufacturer Identifier' zijn. (string(@LongName)=('Substance Manufacturer Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.136-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.1"
                 priority="1057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.2"
                 priority="1056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.3"
                 priority="1055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.4"
                 priority="1053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.5"
                 priority="1052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:SID/hl7v2:SID.4/hl7v2:CE.6"
                 priority="1051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE"
                 priority="1049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.1"
                 priority="1048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.2"
                 priority="1047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3"
                 priority="1045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="1044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="1043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4"
                 priority="1041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="1039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="1038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="1037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="1035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="1034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:OUL_R22.RESULT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="1033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI"
                 priority="1031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.1 is required [min 1x]. (count(hl7v2:CTI.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.1 komt te vaak voor [max 1x]. (count(hl7v2:CTI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.2 komt te vaak voor [max 1x]. (count(hl7v2:CTI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.3 komt te vaak voor [max 1x]. (count(hl7v2:CTI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1"
                 priority="1030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1011') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Item MOET '1011' zijn. (string(@Item)=('1011') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sponsor Study ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @LongName MOET 'Sponsor Study ID' zijn. (string(@LongName)=('Sponsor Study ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.1"
                 priority="1028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.2"
                 priority="1027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.3"
                 priority="1026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.4"
                 priority="1025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2"
                 priority="1023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1022') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Item MOET '1022' zijn. (string(@Item)=('1022') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Study Phase Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @LongName MOET 'Study Phase Identifier' zijn. (string(@LongName)=('Study Phase Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.1"
                 priority="1021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.2"
                 priority="1020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.3"
                 priority="1019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.4"
                 priority="1017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.5"
                 priority="1016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.6"
                 priority="1015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3"
                 priority="1013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1055') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Item MOET '1055' zijn. (string(@Item)=('1055') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Study Scheduled Time Point') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @LongName MOET 'Study Scheduled Time Point' zijn. (string(@LongName)=('Study Scheduled Time Point') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.1"
                 priority="1011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.2"
                 priority="1010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.3"
                 priority="1009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.4"
                 priority="1007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.5"
                 priority="1006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:OUL_R22.SPECIMEN/hl7v2:OUL_R22.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.6"
                 priority="1005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:DSC" priority="1003" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DSC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DSC_segment): element hl7v2:DSC.1 komt te vaak voor [max 1x]. (count(hl7v2:DSC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DSC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DSC_segment): element hl7v2:DSC.2 komt te vaak voor [max 1x]. (count(hl7v2:DSC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:DSC/hl7v2:DSC.1"
                 priority="1002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('14') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DSC_segment): de waarde van @Item MOET '14' zijn. (string(@Item)=('14') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DSC_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Continuation Pointer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DSC_segment): de waarde van @LongName MOET 'Continuation Pointer' zijn. (string(@LongName)=('Continuation Pointer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OUL_R22/hl7v2:DSC/hl7v2:DSC.2"
                 priority="1001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1354') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DSC_segment): de waarde van @Item MOET '1354' zijn. (string(@Item)=('1354') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DSC_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70398') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DSC_segment): de waarde van @Table MOET 'HL70398' zijn. (string(@Table)=('HL70398') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Continuation Style') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DSC_segment): de waarde van @LongName MOET 'Continuation Style' zijn. (string(@LongName)=('Continuation Style') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.38-2016-05-31T000000-closedLab2PublicHealth Resultaatbericht (OUL^R22)-->
   <xsl:template match="text()" priority="-1" mode="M9"/>
   <xsl:template match="@*|node()" priority="-2" mode="M9">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>
</xsl:stylesheet>
